@@ -62,13 +62,13 @@ Atlantik::Atlantik () : KMainWindow ()
 	m_selectServer = 0;
 	m_selectGame = 0;
 	m_selectConfiguration = 0;
-	m_playerSelf = 0;
 	m_atlantikNetwork = 0;
 
 	// Game and network core
 	m_atlanticCore = new AtlanticCore(this, "atlanticCore");
 	initNetworkObject();
 
+	connect(m_atlanticCore, SIGNAL(removeGUI(Player *)), this, SLOT(removeGUI(Player *)));
 	connect(m_atlanticCore, SIGNAL(removeGUI(Trade *)), this, SLOT(removeGUI(Trade *)));
 
 	// Menu,toolbar: Move
@@ -114,7 +114,7 @@ Atlantik::Atlantik () : KMainWindow ()
 	m_serverMsgs->setTextFormat(QTextEdit::PlainText);
 	m_serverMsgs->setReadOnly(true);
 	m_serverMsgs->setHScrollBarMode(QScrollView::AlwaysOff);
-	m_serverMsgs->setFixedWidth(225);
+	m_serverMsgs->setMinimumWidth(200);
 	m_mainLayout->addWidget(m_serverMsgs, 1, 0);
 
 	// LineEdit to enter commands and chat messages.
@@ -166,33 +166,24 @@ void Atlantik::readConfig()
 
 void Atlantik::newPlayer(Player *player)
 {
-	initBoard();
-
-	m_board->addToken(player);
-
-	if (m_selectConfiguration)
-		m_selectConfiguration->addPlayer(player);
-
-	PortfolioView *portfolioView = new PortfolioView(m_atlanticCore, player, m_config.activeColor, m_config.inactiveColor, m_portfolioWidget);
-	m_portfolioViews.append(portfolioView);
-
 	if (player->isSelf())
-	{
-		m_playerSelf = player;
-		connect(player, SIGNAL(changed(Player *)), this, SLOT(playerChanged()));
-	}
-	connect(player, SIGNAL(changed(Player *)), portfolioView, SLOT(playerChanged()));
-	connect(portfolioView, SIGNAL(newTrade(Player *)), m_atlantikNetwork, SLOT(newTrade(Player *)));
-	connect(portfolioView, SIGNAL(estateClicked(Estate *)), m_board, SLOT(prependEstateDetails(Estate *)));
+		m_atlanticCore->setPlayerSelf(player);
 
-	m_portfolioLayout->addWidget(portfolioView);
-	portfolioView->show();
+	initBoard();
+	m_board->addToken(player);
+	addPortfolioView(player);
+
+	// Player::changed() is not connected until later this method, so
+	// we'd better force an update.
+	playerChanged(player);
+
+	connect(player, SIGNAL(changed(Player *)), this, SLOT(playerChanged(Player *)));
+	connect(player, SIGNAL(changed(Player *)), m_board, SLOT(playerChanged(Player *)));
 }
 
 void Atlantik::newEstate(Estate *estate)
 {
 	initBoard();
-
 	m_board->addEstateView(estate, m_config.indicateUnowned, m_config.highliteUnowned, m_config.darkenMortgaged, m_config.quartzEffects);
 }
 
@@ -206,10 +197,20 @@ void Atlantik::newTrade(Trade *trade)
 void Atlantik::newAuction(Auction *auction)
 {
 	initBoard();
-
 	m_board->addAuctionWidget(auction);
 }
 
+void Atlantik::removeGUI(Player *player)
+{
+	// Find and remove portfolioview
+	PortfolioView *portfolioView = findPortfolioView(player);
+	if (portfolioView)
+		m_portfolioViews.remove(portfolioView);
+
+	if (m_board)
+		m_board->removeToken(player);
+}
+
 void Atlantik::removeGUI(Trade *trade)
 {
 	if (TradeDisplay *tradeDisplay = m_tradeGUIMap[trade])
@@ -221,14 +222,20 @@ void Atlantik::showSelectServer()
 	m_selectServer = new SelectServer(m_mainWidget, "selectServer");
 	m_mainLayout->addMultiCellWidget(m_selectServer, 0, 2, 1, 1);
 	m_selectServer->show();
+
 	if (m_selectGame)
 	{
+		disconnect(m_atlantikNetwork, SIGNAL(gameListClear()), m_selectGame, SLOT(slotGameListClear()));
+
 		delete m_selectGame;
 		m_selectGame = 0;
 	}
+
+	m_atlanticCore->reset(true);
+
 	initNetworkObject();
 
-	connect(m_atlantikNetwork, SIGNAL(gameListClear()), this, SLOT(showSelectGame())); // disconnect from selectGame implied by deletion above
+	connect(m_atlantikNetwork, SIGNAL(gameListClear()), this, SLOT(showSelectGame()));
 	connect(m_selectServer, SIGNAL(serverConnect(const QString, int)), m_atlantikNetwork, SLOT(serverConnect(const QString, int)));
 }
 
@@ -241,10 +248,12 @@ void Atlantik::showSelectGame()
 	// Reset core and GUI
 	if (m_board)
 	{
-		delete m_board;
-		m_board = 0;
+		m_board->hide();
+		m_board->reset();
+//		delete m_board;
+//		m_board = 0;
 
-		m_portfolioViews.clear();
+		// m_portfolioViews.clear();
 		m_atlanticCore->reset();
 	}
 
@@ -252,21 +261,19 @@ void Atlantik::showSelectGame()
 	{
 		delete m_selectServer;
 		m_selectServer = 0;
-
-		disconnect(m_atlantikNetwork, SIGNAL(gameListClear()), this, SLOT(showSelectGame()));
 	}
 	if (m_selectConfiguration)
 	{
 		delete m_selectConfiguration;
 		m_selectConfiguration = 0;
-
-		disconnect(m_atlantikNetwork, SIGNAL(gameListClear()), this, SLOT(showSelectGame()));
 	}
 
+	// Game list clear has a different meaning now
+	disconnect(m_atlantikNetwork, SIGNAL(gameListClear()), this, SLOT(showSelectGame()));
 	connect(m_atlantikNetwork, SIGNAL(gameListClear()), m_selectGame, SLOT(slotGameListClear()));
 
-	connect(m_atlantikNetwork, SIGNAL(gameListAdd(QString, QString, QString, QString, QString)), m_selectGame, SLOT(slotGameListAdd(QString, QString, QString, QString, QString)));
-	connect(m_atlantikNetwork, SIGNAL(gameListEdit(QString, QString, QString, QString, QString)), m_selectGame, SLOT(slotGameListEdit(QString, QString, QString, QString, QString)));
+	connect(m_atlantikNetwork, SIGNAL(gameListAdd(QString, QString, QString, QString, QString, bool)), m_selectGame, SLOT(slotGameListAdd(QString, QString, QString, QString, QString, bool)));
+	connect(m_atlantikNetwork, SIGNAL(gameListEdit(QString, QString, QString, QString, QString, bool)), m_selectGame, SLOT(slotGameListEdit(QString, QString, QString, QString, QString, bool)));
 	connect(m_atlantikNetwork, SIGNAL(gameListDel(QString)), m_selectGame, SLOT(slotGameListDel(QString)));
 	connect(m_atlantikNetwork, SIGNAL(gameListEndUpdate()), m_selectGame, SLOT(slotGameListEndUpdate()));
 
@@ -279,6 +286,8 @@ void Atlantik::showSelectConfiguration()
 {
 	if (m_selectGame)
 	{
+		disconnect(m_atlantikNetwork, SIGNAL(gameListClear()), m_selectGame, SLOT(slotGameListClear()));
+
 		delete m_selectGame;
 		m_selectGame = 0;
 	}
@@ -286,12 +295,16 @@ void Atlantik::showSelectConfiguration()
 	if (m_selectConfiguration)
 		return;
 
+	Player *playerSelf = m_atlanticCore->playerSelf();
 	m_selectConfiguration = new SelectConfiguration(m_mainWidget, "selectConfiguration");
+	m_selectConfiguration->setCanStart(playerSelf ? playerSelf->master() : false);
 	m_mainLayout->addMultiCellWidget(m_selectConfiguration, 0, 2, 1, 1);
 	m_selectConfiguration->show();
 
 	connect(m_atlantikNetwork, SIGNAL(gameListClear()), this, SLOT(showSelectGame()));
 	connect(m_atlantikNetwork, SIGNAL(gameOption(QString, QString, QString, QString, QString)), m_selectConfiguration, SLOT(gameOption(QString, QString, QString, QString, QString)));
+	connect(m_atlantikNetwork, SIGNAL(endConfigUpdate()), m_selectConfiguration, SLOT(slotEndUpdate()));
+	connect(m_atlantikNetwork, SIGNAL(gameInit()), m_selectConfiguration, SLOT(initGame()));
 	connect(m_selectConfiguration, SIGNAL(startGame()), m_atlantikNetwork, SLOT(startGame()));
 	connect(m_selectConfiguration, SIGNAL(leaveGame()), m_atlantikNetwork, SLOT(leaveGame()));
 	connect(m_selectConfiguration, SIGNAL(buttonCommand(QString)), m_atlantikNetwork, SLOT(writeData(QString)));
@@ -305,9 +318,7 @@ void Atlantik::initBoard()
 	m_board = new AtlantikBoard(m_atlanticCore, 40, AtlantikBoard::Play, m_mainWidget, "board");
 	m_board->setViewProperties(m_config.indicateUnowned, m_config.highliteUnowned, m_config.darkenMortgaged, m_config.quartzEffects, m_config.animateTokens);
 
-	connect(m_atlantikNetwork, SIGNAL(displayText(QString, QString)), m_board, SLOT(displayText(QString, QString)));
-	connect(m_atlantikNetwork, SIGNAL(displayEstate(Estate *)), m_board, SLOT(insertEstateDetails(Estate *)));
-	connect(m_atlantikNetwork, SIGNAL(displayDefault()), m_board, SLOT(displayDefault()));
+	connect(m_atlantikNetwork, SIGNAL(displayDetails(QString, bool, bool, Estate *)), m_board, SLOT(insertDetails(QString, bool, bool, Estate *)));
 	connect(m_atlantikNetwork, SIGNAL(addCommandButton(QString, QString, bool)), m_board, SLOT(displayButton(QString, QString, bool)));
 	connect(m_atlantikNetwork, SIGNAL(addCloseButton()), m_board, SLOT(addCloseButton()));
 	connect(m_board, SIGNAL(tokenConfirmation(Estate *)), m_atlantikNetwork, SLOT(tokenConfirmation(Estate *)));
@@ -316,6 +327,14 @@ void Atlantik::initBoard()
 
 void Atlantik::showBoard()
 {
+	if (m_selectGame)
+	{
+		disconnect(m_atlantikNetwork, SIGNAL(gameListClear()), m_selectGame, SLOT(slotGameListClear()));
+
+		delete m_selectGame;
+		m_selectGame = 0;
+	}
+
 	if (m_selectConfiguration)
 	{
 		delete m_selectConfiguration;
@@ -326,12 +345,15 @@ void Atlantik::showBoard()
 		initBoard();
 
 	m_mainLayout->addMultiCellWidget(m_board, 0, 2, 1, 1);
+	m_board->displayDefault();
 	m_board->show();
 
 	PortfolioView *portfolioView = 0;
 	for (QPtrListIterator<PortfolioView> it(m_portfolioViews); *it; ++it)
 		if ((portfolioView = dynamic_cast<PortfolioView*>(*it)))
 			portfolioView->buildPortfolio();
+
+	connect(m_atlantikNetwork, SIGNAL(gameListClear()), this, SLOT(showSelectGame()));
 }
 
 void Atlantik::freezeBoard()
@@ -461,7 +483,7 @@ void Atlantik::slotUpdateConfig()
 void Atlantik::slotSendMsg()
 {
 	m_atlantikNetwork->cmdChat(m_input->text());
-	m_input->setText("");
+	m_input->setText(QString::null);
 }
 
 void Atlantik::slotMsgInfo(QString msg)
@@ -486,17 +508,56 @@ void Atlantik::serverMsgsAppend(QString msg)
 	m_serverMsgs->ensureVisible(0, m_serverMsgs->contentsHeight());
 }
 
-void Atlantik::playerChanged()
+void Atlantik::playerChanged(Player *player)
 {
-	m_roll->setEnabled(m_playerSelf->canRoll());
-	m_buyEstate->setEnabled(m_playerSelf->canBuy());
-	m_auctionEstate->setEnabled(m_playerSelf->canBuy());
+	PortfolioView *portfolioView = findPortfolioView(player);
+	if (!portfolioView)
+		portfolioView = addPortfolioView(player);
 
-	// TODO: Should be more finetuned, but monopd doesn't send can_endturn can_usejailcard can_payjail can_jailroll yet
-	m_endTurn->setEnabled(m_playerSelf->hasTurn() && !(m_playerSelf->canRoll() || m_playerSelf->canBuy() || m_playerSelf->inJail()));
-	m_jailCard->setEnabled(m_playerSelf->hasTurn() && m_playerSelf->inJail());
-	m_jailPay->setEnabled(m_playerSelf->hasTurn() && m_playerSelf->inJail());
-	m_jailRoll->setEnabled(m_playerSelf->hasTurn() && m_playerSelf->inJail());
+	Player *playerSelf = m_atlanticCore->playerSelf();
+	if (player == playerSelf)
+	{
+		// We changed ourselves, see if other players (that we know
+		// about) have the same gameId..
+
+		PortfolioView *portfolioView = 0;
+		for (QPtrListIterator<PortfolioView> it(m_portfolioViews); *it; ++it)
+			if ((portfolioView = dynamic_cast<PortfolioView*>(*it)))
+			{
+				Player *pTmp = portfolioView->player();
+				if (pTmp->gameId() == playerSelf->gameId())
+					portfolioView->show();
+				else
+					portfolioView->hide();
+			}
+
+		if (m_selectConfiguration)
+			m_selectConfiguration->setCanStart(player->master());
+
+		m_roll->setEnabled(player->canRoll());
+		m_buyEstate->setEnabled(player->canBuy());
+		m_auctionEstate->setEnabled(player->canAuction());
+
+		// TODO: Should be more finetuned, but monopd doesn't send can_endturn can_payjail can_jailroll yet
+		m_endTurn->setEnabled(player->hasTurn() && !(player->canRoll() || player->canBuy() || player->inJail()));
+		m_jailCard->setEnabled(player->canUseCard());
+		m_jailPay->setEnabled(player->hasTurn() && player->inJail());
+		m_jailRoll->setEnabled(player->hasTurn() && player->inJail());
+	}
+	else
+	{
+		// Another player changed, check if we need to show or hide
+		// his/her portfolioView.
+		if (playerSelf)
+		{
+			if (player->gameId() == playerSelf->gameId())
+				portfolioView->show();
+			else
+				portfolioView->hide();
+		}
+		else if (player->gameId() == -1)
+			portfolioView->hide();
+	}
 }
 
 void Atlantik::initNetworkObject()
@@ -507,7 +568,7 @@ void Atlantik::initNetworkObject()
 		return;
 	}
 
-	m_atlantikNetwork = new AtlantikNetwork(m_atlanticCore, this, "atlantikNetwork");
+	m_atlantikNetwork = new AtlantikNetwork(m_atlanticCore);
 	connect(m_atlantikNetwork, SIGNAL(msgInfo(QString)), this, SLOT(slotMsgInfo(QString)));
 	connect(m_atlantikNetwork, SIGNAL(msgError(QString)), this, SLOT(slotMsgError(QString)));
 	connect(m_atlantikNetwork, SIGNAL(msgChat(QString, QString)), this, SLOT(slotMsgChat(QString, QString)));
@@ -515,6 +576,7 @@ void Atlantik::initNetworkObject()
 	connect(m_atlantikNetwork, SIGNAL(connectionSuccess()), this, SLOT(slotNetworkConnected()));
 	connect(m_atlantikNetwork, SIGNAL(connectionFailed(int)), this, SLOT(slotNetworkError(int)));
 
+	connect(m_atlantikNetwork, SIGNAL(gameListClear()), this, SLOT(showSelectGame()));
 	connect(m_atlantikNetwork, SIGNAL(gameConfig()), this, SLOT(showSelectConfiguration()));
 	connect(m_atlantikNetwork, SIGNAL(gameInit()), this, SLOT(initBoard()));
 	connect(m_atlantikNetwork, SIGNAL(gameRun()), this, SLOT(showBoard()));
@@ -525,6 +587,8 @@ void Atlantik::initNetworkObject()
 	connect(m_atlantikNetwork, SIGNAL(newTrade(Trade *)), this, SLOT(newTrade(Trade *)));
 	connect(m_atlantikNetwork, SIGNAL(newAuction(Auction *)), this, SLOT(newAuction(Auction *)));
 
+	connect(m_atlantikNetwork, SIGNAL(clientCookie(QString)), this, SLOT(clientCookie(QString)));
+
 	connect(this, SIGNAL(rollDice()), m_atlantikNetwork, SLOT(rollDice()));
 	connect(this, SIGNAL(buyEstate()), m_atlantikNetwork, SLOT(buyEstate()));
 	connect(this, SIGNAL(auctionEstate()), m_atlantikNetwork, SLOT(auctionEstate()));
@@ -533,3 +597,50 @@ void Atlantik::initNetworkObject()
 	connect(this, SIGNAL(jailPay()), m_atlantikNetwork, SLOT(jailPay()));
 	connect(this, SIGNAL(jailRoll()), m_atlantikNetwork, SLOT(jailRoll()));
 }
+
+void Atlantik::clientCookie(QString cookie)
+{
+	KConfig *config = kapp->config();
+
+	if (cookie.isNull())
+	{
+		if (config->hasGroup("Reconnection"))
+			config->deleteGroup("Reconnection", true);
+	}
+	else if (m_atlantikNetwork)
+	{
+		config->setGroup("Reconnection");
+		config->writeEntry("Host", m_atlantikNetwork->host());
+		config->writeEntry("Port", m_atlantikNetwork->port());
+		config->writeEntry("Cookie", cookie);
+	}
+	else
+		return;
+
+	config->sync();
+}
+
+PortfolioView *Atlantik::addPortfolioView(Player *player)
+{
+	PortfolioView *portfolioView = new PortfolioView(m_atlanticCore, player, m_config.activeColor, m_config.inactiveColor, m_portfolioWidget);
+	m_portfolioViews.append(portfolioView);
+
+	connect(player, SIGNAL(changed(Player *)), portfolioView, SLOT(playerChanged()));
+	connect(portfolioView, SIGNAL(newTrade(Player *)), m_atlantikNetwork, SLOT(newTrade(Player *)));
+	connect(portfolioView, SIGNAL(estateClicked(Estate *)), m_board, SLOT(prependEstateDetails(Estate *)));
+
+	m_portfolioLayout->addWidget(portfolioView);
+	portfolioView->show();
+
+	return portfolioView;
+}
+
+PortfolioView *Atlantik::findPortfolioView(Player *player)
+{
+	PortfolioView *portfolioView = 0;
+	for (QPtrListIterator<PortfolioView> it(m_portfolioViews); (portfolioView = *it) ; ++it)
+		if (player == portfolioView->player())
+			return portfolioView;
+
+	return 0;
+}
