@@ -36,7 +36,7 @@
 //#include "atlantik.h"
 //#include "trade_widget.h"
 
-AtlantikNetwork::AtlantikNetwork(AtlanticCore *atlanticCore, QObject *parent, const char *name) : KExtendedSocket(0, 0, KExtendedSocket::inputBufferedSocket)
+AtlantikNetwork::AtlantikNetwork(AtlanticCore *atlanticCore) : KExtendedSocket(0, 0, KExtendedSocket::inputBufferedSocket)
 {
 	m_atlanticCore = atlanticCore;
 	m_textStream = new QTextStream(this);
@@ -181,10 +181,11 @@ void AtlantikNetwork::tradeAccept(Trade *trade)
 {
 	QString msg(".Ta");
 	msg.append(QString::number(trade ? trade->tradeId() : -1));
+	msg.append(":");
+	msg.append(QString::number(trade ? trade->revision() : -1));
 	writeData(msg);
 }
 
-
 void AtlantikNetwork::auctionBid(Auction *auction, int amount)
 {
 	QString msg(".ab");
@@ -280,32 +281,23 @@ void AtlantikNetwork::processNode(QDomNode n)
 				if (!a.isNull())
 				{
 					estateId = a.value().toInt();
-					Estate *estate;
-					if ((estate = m_atlanticCore->findEstate(a.value().toInt())))
-					{
-						emit displayEstate(estate);
-						// TODO: merge into displayEstate, or statusbar
-						emit msgInfo(e.attributeNode(QString("text")).value());
+					Estate *estate = m_atlanticCore->findEstate(a.value().toInt());
 
-						bool hasButtons = false;
-						for( QDomNode nButtons = n.firstChild() ; !nButtons.isNull() ; nButtons = nButtons.nextSibling() )
+					emit displayDetails(e.attributeNode(QString("text")).value(), e.attributeNode(QString("cleartext")).value().toInt(), e.attributeNode(QString("clearbuttons")).value().toInt(), estate);
+
+					bool hasButtons = false;
+					for( QDomNode nButtons = n.firstChild() ; !nButtons.isNull() ; nButtons = nButtons.nextSibling() )
+					{
+						QDomElement eButton = nButtons.toElement();
+						if (!eButton.isNull() && eButton.tagName() == "button")
 						{
-							QDomElement eButton = nButtons.toElement();
-							if (!eButton.isNull() && eButton.tagName() == "button")
-							{
-								QDomElement eButton = nButtons.toElement();
-								if (!eButton.isNull() && eButton.tagName() == "button")
-								{
-									emit addCommandButton(eButton.attributeNode(QString("command")).value(), eButton.attributeNode(QString("caption")).value(), eButton.attributeNode(QString("enabled")).value().toInt());
-									hasButtons = true;
-								}
-							}
+							emit addCommandButton(eButton.attributeNode(QString("command")).value(), eButton.attributeNode(QString("caption")).value(), eButton.attributeNode(QString("enabled")).value().toInt());
+							hasButtons = true;
 						}
-						if (!hasButtons)
-							emit addCloseButton();
 					}
-					else
-						displayDefault();
+
+					if (!hasButtons)
+						emit addCloseButton();
 				}
 			}
 			else if (e.tagName() == "updategamelist")
@@ -323,9 +315,9 @@ void AtlantikNetwork::processNode(QDomNode n)
 						if (type=="del")
 							emit gameListDel(e_game.attributeNode(QString("id")).value());
 						else if (type=="edit")
-							emit gameListEdit(e_game.attributeNode(QString("id")).value(), e_game.attributeNode(QString("name")).value(), e_game.attributeNode(QString("description")).value(), e_game.attributeNode(QString("players")).value(), e_game.attributeNode(QString("gametype")).value());
+							emit gameListEdit(e_game.attributeNode(QString("id")).value(), e_game.attributeNode(QString("name")).value(), e_game.attributeNode(QString("description")).value(), e_game.attributeNode(QString("players")).value(), e_game.attributeNode(QString("gametype")).value(), e_game.attributeNode(QString("canbejoined")).value().toInt());
 						else if (type=="add" || type=="full")
-							emit gameListAdd(e_game.attributeNode(QString("id")).value(), e_game.attributeNode(QString("name")).value(), e_game.attributeNode(QString("description")).value(), e_game.attributeNode(QString("players")).value(), e_game.attributeNode(QString("gametype")).value());
+							emit gameListAdd(e_game.attributeNode(QString("id")).value(), e_game.attributeNode(QString("name")).value(), e_game.attributeNode(QString("description")).value(), e_game.attributeNode(QString("players")).value(), e_game.attributeNode(QString("gametype")).value(), e_game.attributeNode(QString("canbejoined")).value().toInt());
 					}
 					n_game = n_game.nextSibling();
 				}
@@ -341,6 +333,9 @@ void AtlantikNetwork::processNode(QDomNode n)
 					// TODO: move to Atlantik::slotNetworkConnected(), not needed on auto-join
 					cmdGamesList();
 				}
+				a = e.attributeNode(QString("cookie"));
+				if (!a.isNull())
+					emit clientCookie(a.value());
 			}
 			else if (e.tagName() == "configupdate")
 			{
@@ -357,6 +352,7 @@ void AtlantikNetwork::processNode(QDomNode n)
 							emit gameOption(eOption.attributeNode(QString("title")).value(), eOption.attributeNode(QString("type")).value(), eOption.attributeNode(QString("value")).value(), eOption.attributeNode(QString("edit")).value(), eOption.attributeNode(QString("command")).value());
 					}
 				}
+				emit endConfigUpdate();
 			}
 			else if (e.tagName() == "gameupdate")
 			{
@@ -381,6 +377,18 @@ void AtlantikNetwork::processNode(QDomNode n)
 						emit gameEnd();
 				}
 			}
+			else if (e.tagName() == "deleteplayer")
+			{
+				a = e.attributeNode(QString("playerid"));
+				if (!a.isNull())
+				{
+					int playerId = a.value().toInt();
+
+					Player *player = m_atlanticCore->findPlayer(playerId);
+					if (player)
+						m_atlanticCore->removePlayer(player);
+				}
+			}
 			else if (e.tagName() == "playerupdate")
 			{
 				int playerId = -1;
@@ -408,6 +416,11 @@ void AtlantikNetwork::processNode(QDomNode n)
 					if (player && !a.isNull())
 						player->setName(a.value());
 
+					// Update player game
+					a = e.attributeNode(QString("game"));
+					if (player && !a.isNull())
+						player->setGame(a.value().toInt());
+
 					// Update player host
 					a = e.attributeNode(QString("host"));
 					if (player && !a.isNull())
@@ -418,6 +431,18 @@ void AtlantikNetwork::processNode(QDomNode n)
 					if (player && !a.isNull())
 						player->setMoney(a.value().toInt());
 
+					a = e.attributeNode(QString("master"));
+					if (player && !a.isNull())
+						player->setMaster(a.value().toInt());
+
+					a = e.attributeNode(QString("bankrupt"));
+					if (player && !a.isNull())
+						player->setBankrupt(a.value().toInt());
+
+					a = e.attributeNode(QString("hasdebt"));
+					if (player && !a.isNull())
+						player->setHasDebt(a.value().toInt());
+
 					a = e.attributeNode(QString("hasturn"));
 					if (player && !a.isNull())
 						player->setHasTurn(a.value().toInt());
@@ -432,6 +457,16 @@ void AtlantikNetwork::processNode(QDomNode n)
 					if (player && !a.isNull())
 						player->setCanBuy(a.value().toInt());
 
+					// Update whether player can auction
+					a = e.attributeNode(QString("canauction"));
+					if (player && !a.isNull())
+						player->setCanAuction(a.value().toInt());
+
+					// Update whether player can use a card
+					a = e.attributeNode(QString("canusecard"));
+					if (player && !a.isNull())
+						player->setCanUseCard(a.value().toInt());
+
 					// Update whether player is jailed
 					a = e.attributeNode(QString("jailed"));
 					if (player && !a.isNull())
@@ -453,8 +488,13 @@ void AtlantikNetwork::processNode(QDomNode n)
 						if (!a.isNull())
 							directMove = a.value().toInt();
 
-						if (estate)
-							player->setLocation(estate);
+						if (player && estate)
+						{
+							if (directMove)
+								player->setLocation(estate);
+							else
+								player->setDestination(estate);
+						}
 					}
 
 					// Emit signal so GUI implementations can create view(s)
@@ -474,7 +514,7 @@ void AtlantikNetwork::processNode(QDomNode n)
 				{
 					int groupId = a.value().toInt();
 
-					EstateGroup *estateGroup;
+					EstateGroup *estateGroup = 0;
 					bool b_newEstateGroup = false;
 					
 					if (!(estateGroup = m_atlanticCore->findEstateGroup(groupId)))
@@ -512,18 +552,17 @@ void AtlantikNetwork::processNode(QDomNode n)
 					bool b_newEstate = false;
 
 					// FIXME: allow any estateId, GUI should not use it to determin its geometry
-					if (estateId >=0 && estateId < 100 && !(estate = m_atlanticCore->findEstate(a.value().toInt())))
+					if (estateId >= 0 && estateId < 100 && !(estate = m_atlanticCore->findEstate(a.value().toInt())))
 					{
 						// Create estate object
 						estate = m_atlanticCore->newEstate(estateId);
+						b_newEstate = true;
 
 						QObject::connect(estate, SIGNAL(estateToggleMortgage(Estate *)), this, SLOT(estateToggleMortgage(Estate *)));
 						QObject::connect(estate, SIGNAL(estateHouseBuy(Estate *)), this, SLOT(estateHouseBuy(Estate *)));
 						QObject::connect(estate, SIGNAL(estateHouseSell(Estate *)), this, SLOT(estateHouseSell(Estate *)));
 						QObject::connect(estate, SIGNAL(newTrade(Player *)), this, SLOT(newTrade(Player *)));
 
-						b_newEstate = true;
-
 						// Players without estate should get one
 						Player *player = 0;
 						QPtrList<Player> playerList = m_atlanticCore->players();
@@ -602,13 +641,12 @@ void AtlantikNetwork::processNode(QDomNode n)
 				{
 					int tradeId = a.value().toInt();
 
-					Trade *trade;
+					Trade *trade = m_atlanticCore->findTrade(tradeId);
 					bool b_newTrade = false;
-					if (!(trade = m_trades[tradeId]))
+					if (!trade)
 					{
 						// Create trade object
 						trade = m_atlanticCore->newTrade(tradeId);
-						m_trades[tradeId] = trade;
 
 						QObject::connect(trade, SIGNAL(updateEstate(Trade *, Estate *, Player *)), this, SLOT(tradeUpdateEstate(Trade *, Estate *, Player *)));
 						QObject::connect(trade, SIGNAL(updateMoney(Trade *, unsigned int, Player *, Player *)), this, SLOT(tradeUpdateMoney(Trade *, unsigned int, Player *, Player *)));
@@ -617,6 +655,10 @@ void AtlantikNetwork::processNode(QDomNode n)
 						b_newTrade = true;
 					}
 
+					a = e.attributeNode(QString("revision"));
+					if (trade && !a.isNull())
+						trade->setRevision(a.value().toInt());
+
 					QString type = e.attributeNode(QString("type")).value();
 					if (type=="new")
 					{
@@ -633,7 +675,10 @@ void AtlantikNetwork::processNode(QDomNode n)
 							{
 								Player *player = m_atlanticCore->findPlayer(e_player.attributeNode(QString("playerid")).value().toInt());
 								if (trade && player)
+								{
 									trade->addPlayer(player);
+									QObject::connect(m_atlanticCore, SIGNAL(removePlayer(Player *)), trade, SLOT(removePlayer(Player *)));
+								}
 							}
 							n_player = n_player.nextSibling();
 						}
@@ -643,7 +688,6 @@ void AtlantikNetwork::processNode(QDomNode n)
 					else if (type=="completed" && trade)
 					{
 						m_atlanticCore->removeTrade(trade);
-						m_trades[tradeId] = 0;
 						trade = 0;
 					}
 					else if (type=="rejected")
@@ -654,7 +698,6 @@ void AtlantikNetwork::processNode(QDomNode n)
 						if (player && player->isSelf())
 						{
 							m_atlanticCore->removeTrade(trade);
-							m_trades[tradeId] = 0;
 							trade = 0;
 						}
 					}
@@ -793,7 +836,6 @@ void AtlantikNetwork::processNode(QDomNode n)
 
 void AtlantikNetwork::serverConnect(const QString host, int port)
 {
-	kdDebug() << "AtlantikNetwork::serverConnect(" << host << ", " << QString::number(port) << ")" << endl;
 	setAddress(host, port);
 	enableRead(true);
 	startAsyncConnect();
