@@ -273,6 +273,7 @@ KAstTopLevel::KAstTopLevel() : KMainWindow(0)
 
     readSettings();
     slotNewGame();
+    installEventFilter(this);
 }
 
 KAstTopLevel::~KAstTopLevel()
@@ -296,7 +297,6 @@ void KAstTopLevel::initKAction()
     KStdAction::preferences(this, SLOT( slotPref() ), actionCollection());
 
 // keyboard-only actions
-    actionCollection()->setAutoConnectShortcuts(false);
     keycodes.insert(Thrust, new KAction(i18n("Thrust"), Qt::Key_Up, 0, 0, actionCollection(), "Thrust"));
     keycodes.insert(RotateLeft, new KAction(i18n("Rotate Left"), Qt::Key_Left, 0, 0, actionCollection(), "RotateLeft"));
     keycodes.insert(RotateRight, new KAction(i18n("Rotate Right"), Qt::Key_Right, 0, 0, actionCollection(), "RotateRight"));
@@ -304,7 +304,7 @@ void KAstTopLevel::initKAction()
     keycodes.insert(Teleport, new KAction(i18n("Teleport"), Qt::Key_Z, 0, 0, actionCollection(), "Teleport"));
     keycodes.insert(Brake, new KAction(i18n("Brake"), Qt::Key_X, 0, 0, actionCollection(), "Brake"));
     keycodes.insert(Shield, new KAction(i18n("Shield"), Qt::Key_S, 0, 0, actionCollection(), "Shield"));
-    keycodes.insert(Launch, new KAction(i18n("Launch"), Qt::Key_L, 0, 0, actionCollection(), "Launch"));
+    launchAction = new KAction(i18n("Launch"), Qt::Key_L, this, SLOT(slotLaunch()), actionCollection(), "Launch");
     
     createGUI("kasteroidsui.rc");
 }
@@ -351,14 +351,30 @@ return; // remove this and the above when the sound below is working correctly
     if ( sound ) {
         QString *filename = soundDict[ snd ];
         if (filename) {
-            kdDebug() "playing " << *filename << endl;
+            kdDebug() << "playing " << *filename << endl;
             if(!soundServer->isNull()) soundServer->play(filename->latin1());
         }
     }
 #endif
 }
 
-void KAstTopLevel::keyPressEvent( QKeyEvent *event )
+bool KAstTopLevel::eventFilter( QObject* /* object */, QEvent *event )
+{
+    QKeyEvent *e = dynamic_cast<QKeyEvent*>(event);
+    if (event->type() == QEvent::AccelOverride)
+    {
+        if (processKeyPress(e)) return true;
+        else return false;
+    }
+    else if (event->type() == 7) // 7 == QEvent::KeyRelease
+    {
+        if (processKeyRelease(e)) return true;
+        else return false;
+	}
+	return false;
+}
+
+bool KAstTopLevel::processKeyPress( QKeyEvent *event )
 {
     KKey key(event);
     Action a = Invalid;
@@ -405,16 +421,13 @@ void KAstTopLevel::keyPressEvent( QKeyEvent *event )
             break;
 
         case Invalid:
-            break;
-
         default:
-            event->ignore();
-            return;
+            return false;
     }
-    event->accept();
+    return true;
 }
 
-void KAstTopLevel::keyReleaseEvent( QKeyEvent *event )
+bool KAstTopLevel::processKeyRelease( QKeyEvent *event )
 {
     KKey key(event);
     Action a = Invalid;
@@ -457,29 +470,11 @@ void KAstTopLevel::keyReleaseEvent( QKeyEvent *event )
             view->teleport( false );
             break;
 
-        case Launch:
-            if ( waitShip )
-            {
-                view->newShip();
-                waitShip = false;
-                view->hideText();
-            }
-            else
-            {
-                event->ignore();
-                return;
-            }
-            break;
-
         case Invalid:
-            break;
-
         default:
-            event->ignore();
-            return;
+            return false;
     }
-
-    event->accept();
+    return true;
 }
 
 void KAstTopLevel::focusInEvent( QFocusEvent *e )
@@ -506,7 +501,7 @@ void KAstTopLevel::slotNewGame()
     view->setRockSpeed( levels[0].rockSpeed );
     view->addRocks( levels[0].nrocks );
     view->showText( i18n( "Press %1 to launch." )
-                    .arg(keycodes[Launch]->shortcut().seq(0).toString()),
+                    .arg(launchAction->shortcut().seq(0).toString()),
                     yellow );
     waitShip = true;
     isPaused = false;
@@ -531,7 +526,7 @@ void KAstTopLevel::slotShipKilled()
     {
         waitShip = true;
         view->showText( i18n( "Ship Destroyed. Press %1 to launch.")
-                        .arg(keycodes[Launch]->shortcut().seq(0).toString()),
+                        .arg(launchAction->shortcut().seq(0).toString()),
                         yellow );
     }
     else
@@ -597,15 +592,23 @@ void KAstTopLevel::slotRocksRemoved()
 
 void KAstTopLevel::slotKeyConfig()
 {
+    view->pause( true );
     KKeyDialog::configure( actionCollection(), this );
+    if ( waitShip ) view->showText( i18n( "Press %1 to launch." )
+                    .arg(launchAction->shortcut().seq(0).toString()),
+                    yellow, false );
+    
+    view->pause( false );
 }
 
 void KAstTopLevel::slotPref()
 {
+    view->pause( true );
     PrefDialog *pref = new PrefDialog( this );
     if ( pref->exec() )
         readSettings();
     delete pref;
+    view->pause( false );
 }
 
 void KAstTopLevel::slotShowHighscores()
@@ -650,5 +653,24 @@ void KAstTopLevel::slotPause()
     KMessageBox::information( this,
                               i18n("KAsteroids is paused"),
                               i18n("Paused") );
+    
+    //Hack (montel@kde.org)
+    //To create "pause" action we display a messagebox
+    //and we "play" when we close this messagebox
+    //so before this action was 'checked/uncheched'
+    //so I force to unchecked it when we close messagebox.
+    KToggleAction * act = (KToggleAction *)(sender());
+    act->setChecked(false);
+
     view->pause( false );
 }
+
+void KAstTopLevel::slotLaunch()
+{
+    if ( waitShip )
+    {
+        view->newShip();
+        waitShip = false;
+        view->hideText();
+    }
+}
