@@ -50,7 +50,7 @@ void KBAIPlayer::init(KBattleField *battle_field, KShipList *ai_shiplist)
 	{
 		QRect rect = m_battleField->enemyRect();
 		int grid = m_battleField->gridSize();
-		m_fieldRect = QRect(0, 0, (rect.width() / grid) + 1, (rect.height() / grid) + 1);
+		m_fieldRect = QRect(0, 0, (rect.width() / grid), (rect.height() / grid));
 	}
 }
 
