@@ -1,11 +1,11 @@
 /* Class Board
- * 
+ *
  *   with methods for
  *    - play/take back moves
  *    - generate allowed moves
  *    - calculate rating for position
- *    - search for best move 
- * 
+ *    - search for best move
+ *
  * Josef Weidendorfer, 28.8.97
 */
 
@@ -37,11 +37,11 @@ static int normalCount, pushCount, outCount, cutoffCount;
 void PrincipalVariation::clear(int d)
 {
 	int i,j;
-	
+
 	for(i=0;i<maxDepth;i++)
 	  for(j=0;j<maxDepth;j++) {
 		  move[i][j].type = Move::none;
-	  }	
+	  }
 	actMaxDepth = (d<maxDepth) ? d:maxDepth-1;
 }
 
@@ -89,17 +89,17 @@ int Board::order[]={
 /* See EvalScheme.{h|cpp}
  *
   // Ratings for fields are calculated out of these values
-  // (see setFieldValues)  
+  // (see setFieldValues)
   int Board::ringValue[] = { 45, 35, 25, 10, 0 };
   int Board::ringDiff[]  = {  0, 10, 10,  8, 5 };
-  
-  // Value added to board rating according to the difference of 
+
+  // Value added to board rating according to the difference of
   // stones in game of player1 and player2
   int Board::stoneValue[]= { 0,-800,-1800,-3000,-4400,-6000 };
-  
+
   // Default Values for moves values (see Move.h)
   int Board::moveValue[]= { 40,30,30, 15,14,13, 5,5,5, 2,2,2, 1 };
-  
+
   // Default Values for inARow values (see Move.h)
   int Board::inARowValue[]= { 2, 5, 4, 3 };
 */
@@ -140,9 +140,9 @@ void Board::setFieldValues()
     ringValue[i] = _evalScheme->ringValue(i);
     if (ringDiff[i]<1) ringDiff[i]=1;
   }
-  
+
   fieldValue[0] = ringValue[0];
-  for(i=1;i<7;i++) 
+  for(i=1;i<7;i++)
     fieldValue[i] = ringValue[1] + ((j+=k) % ringDiff[1]);
   for(i=7;i<19;i++)
     fieldValue[i] = ringValue[2] + ((j+=k) % ringDiff[2]);
@@ -157,7 +157,7 @@ void Board::setFieldValues()
 void Board::begin(int startColor)
 {
   int i;
-  
+
   for(i=0;i<AllFields;i++)
     field[i] = startBoard[i];
   storedFirst = storedLast = 0;
@@ -169,7 +169,7 @@ void Board::begin(int startColor)
 void Board::clear()
 {
   int i;
-  
+
   for(i=0;i<AllFields;i++)
     field[i] = (startBoard[i] == out) ? out: free;
   storedFirst = storedLast = 0;
@@ -184,48 +184,48 @@ void Board::generateFieldMoves(int startField, MoveList& list)
   int opponent = (color == color1) ? color2 : color1;
 
   Q_ASSERT( field[startField] == color );
-  
+
   /* 6 directions	*/
   for(d=1;d<7;d++) {
     dir = direction[d];
-    
+
     /* 2nd field */
     c = field[actField = startField+dir];
-    if (c == free) {			
+    if (c == free) {
       /* (c .) */
       list.insert(startField, d, Move::move1);
       continue;
-    }		
-    if (c != color) 
+    }
+    if (c != color)
       continue;
-    
+
     /* 2nd == color */
-    
+
     left = (field[startField+direction[d-1]] == free);
     if (left) {
       left = (field[actField+direction[d-1]] == free);
-      if (left) 
+      if (left)
 	/* 2 left */
 	list.insert(startField, d, Move::left2);
     }
-    
+
     right = (field[startField+direction[d+1]] == free);
     if (right) {
       right = (field[actField+direction[d+1]] == free);
-      if (right) 
+      if (right)
 	/* 2 right */
 	list.insert(startField, d, Move::right2);
     }
-    
+
     /* 3rd field */
     c = field[actField += dir];
     if (c == free) {
       /* (c c .) */
       list.insert(startField, d, Move::move2);
       continue;
-    }		
+    }
     else if (c == opponent) {
-      
+
       /* 4th field */
       c = field[actField += dir];
       if (c == free) {
@@ -240,21 +240,21 @@ void Board::generateFieldMoves(int startField, MoveList& list)
     }
     if (c != color)
       continue;
-    
+
     /* 3nd == color */
 
     if (left) {
-      if (field[actField+direction[d-1]] == free) 
+      if (field[actField+direction[d-1]] == free)
 	/* 3 left */
 	list.insert(startField, d, Move::left3);
     }
-    
+
     if (right) {
       if (field[actField+direction[d+1]] == free)
 	/* 3 right */
 	list.insert(startField, d, Move::right3);
     }
-    
+
     /* 4th field */
     c = field[actField += dir];
     if (c == free) {
@@ -264,9 +264,9 @@ void Board::generateFieldMoves(int startField, MoveList& list)
     }
     if (c != opponent)
       continue;
-    
+
     /* 4nd == opponent */
-    
+
     /* 5. field */
     c = field[actField += dir];
     if (c == free) {
@@ -281,9 +281,9 @@ void Board::generateFieldMoves(int startField, MoveList& list)
     }
     if (c != opponent)
       continue;
-    
+
     /* 5nd == opponent */
-    
+
     /* 6. field */
     c = field[actField += dir];
     if (c == free) {
@@ -317,13 +317,13 @@ void Board::playMove(const Move& m)
 	int opponent = (color == color1) ? color2:color1;
 
 	CHECK( isConsistent() );
-	
+
 	if (++storedLast == MvsStored) storedLast = 0;
-	
+
 	/* Buffer full -> delete oldest entry */
 	if (storedLast == storedFirst)
 	  	if (++storedFirst == MvsStored) storedFirst = 0;
-	
+
 	storedMove[storedLast] = m;
 
 	f = m.field;
@@ -331,7 +331,7 @@ void Board::playMove(const Move& m)
 	CHECK( field[f] == color );
 	field[f] = free;
 	dir = direction[m.direction];
-	
+
 	switch(m.type) {
 	 case Move::out2:        /* (c c c o o |) */
 		CHECK( field[f + dir] == color );
@@ -340,7 +340,7 @@ void Board::playMove(const Move& m)
 		CHECK( field[f + 4*dir] == opponent );
 		CHECK( field[f + 5*dir] == out );
 		field[f + 3*dir] = color;
-		break;		
+		break;
 	 case Move::out1with3:   /* (c c c o |)   */
 		CHECK( field[f + dir] == color );
 		CHECK( field[f + 2*dir] == color );
@@ -374,7 +374,7 @@ void Board::playMove(const Move& m)
 		field[f + 3*dir] = color;
 		field[f + 5*dir] = opponent;
 		break;
-	 case Move::left3:		
+	 case Move::left3:
 		dir2 = direction[m.direction-1];
 		CHECK( field[f + dir] == color );
 		CHECK( field[f + 2*dir] == color );
@@ -446,13 +446,13 @@ void Board::playMove(const Move& m)
 		  color2Count--;
 		else
 		  color1Count--;
-	}       
-	
+	}
+
 	/* change actual color */
 	color = opponent;
-	
+
 	CHECK( isConsistent() );
-	
+
 }
 
 bool Board::takeBack()
@@ -460,26 +460,26 @@ bool Board::takeBack()
   int f, dir, dir2;
   int opponent = color;
   Move& m = storedMove[storedLast];
-  
+
   CHECK( isConsistent() );
-  
+
   if (storedFirst == storedLast) return false;
-  
+
   /* change actual color */
-  color = (color == color1) ? color2:color1;	
-  
+  color = (color == color1) ? color2:color1;
+
   if (m.isOutMove()) {
     if (color == color1)
       color2Count++;
     else
       color1Count++;
-  }       
-  
+  }
+
   f = m.field;
   CHECK( field[f] == free );
   field[f] = color;
   dir = direction[m.direction];
-  
+
   switch(m.type) {
   case Move::out2:        /* (. c c c o |) => (c c c o o |) */
     CHECK( field[f + dir] == color );
@@ -588,11 +588,11 @@ bool Board::takeBack()
   default:
     break;
   }
-  
+
   if (--storedLast < 0) storedLast = MvsStored-1;
-  
+
   CHECK( isConsistent() );
-  
+
   return true;
 }
 
@@ -611,17 +611,17 @@ int Board::movesStored()
  *
  * Returns number of found moves
  */
-void Board::countFrom(int startField, int color, 
+void Board::countFrom(int startField, int color,
 		      MoveTypeCounter& TCounter,
 		      InARowCounter& CCounter)
 {
   int d, dir, c, actField, c2;
   bool left, right;
-  
+
   /* 6 directions	*/
   for(d=1;d<7;d++) {
     dir = direction[d];
-    
+
     /* 2nd field */
     c = field[actField = startField+dir];
     if (c == free) {
@@ -631,16 +631,16 @@ void Board::countFrom(int startField, int color,
 
     if (c != color)
       continue;
-    
+
     /* 2nd == color */
-    
+
     CCounter.incr( InARowCounter::inARow2 );
 
     /* left side move 2 */
     left = (field[startField+direction[d-1]] == free);
     if (left) {
       left = (field[actField+direction[d-1]] == free);
-      if (left) 
+      if (left)
 	TCounter.incr( Move::left2 );
     }
 
@@ -648,7 +648,7 @@ void Board::countFrom(int startField, int color,
     right = (field[startField+direction[d+1]] == free);
     if (right) {
       right = (field[actField+direction[d+1]] == free);
-      if (right) 
+      if (right)
 	TCounter.incr( Move::right2 );
     }
 
@@ -663,7 +663,7 @@ void Board::countFrom(int startField, int color,
       continue;
     }
     else if (c != color) {
-      
+
       /* 4th field */
       c = field[actField += dir];
       if (c == free) {
@@ -676,7 +676,7 @@ void Board::countFrom(int startField, int color,
       }
       continue;
     }
-    
+
     /* 3nd == color */
 
     CCounter.incr( InARowCounter::inARow3 );
@@ -684,14 +684,14 @@ void Board::countFrom(int startField, int color,
     /* left side move 3 */
     if (left) {
       left = (field[actField+direction[d-1]] == free);
-      if (left) 
+      if (left)
 	TCounter.incr( Move::left3 );
     }
 
     /* right side move 3 */
     if (right) {
       right = (field[actField+direction[d+1]] == free);
-      if (right) 
+      if (right)
 	TCounter.incr( Move::right3 );
     }
 
@@ -781,8 +781,8 @@ int Board::validState()
 
   int c1 = 0, c2 = 0;
   int i,j, moveCount, res;
-       
-  for(i=0;i<AllFields;i++) {              
+
+  for(i=0;i<AllFields;i++) {
     j=field[i];
     if (j == color1) c1++;
     if (j == color2) c2++;
@@ -794,11 +794,11 @@ int Board::validState()
   color2Count = c2;
   moveCount = tc.sum();
 
-  if (c1==0 && c2==0) 
+  if (c1==0 && c2==0)
     res = empty;
-  else if (c1>8 && c1<15 && c2>8 && c2<15 && moveCount>0 ) 
+  else if (c1>8 && c1<15 && c2>8 && c2<15 && moveCount>0 )
     res = valid;
-  else 
+  else
     res = invalid;
 
 #ifdef MYTRACE
@@ -816,7 +816,7 @@ int Board::validState()
 
 
 /* Calculate a evaluation for actual position
- * 
+ *
  * A higher value means a better position for opponent
  * NB: This means a higher value for better position of
  *     'color before last move'
@@ -841,7 +841,7 @@ int Board::calcEvaluation()
   else {
 
     /* Calculate fieldValueSum and count move types and connectivity */
-    for(i=0;i<RealFields;i++) {		  
+    for(i=0;i<RealFields;i++) {
       j=field[f=order[i]];
       if (j == free) continue;
       if (j == color) {
@@ -853,28 +853,28 @@ int Board::calcEvaluation()
 	fieldValueSum += fieldValue[i];
       }
     }
-    
+
     /* If color can't do any moves, opponent wins... */
-    if (tcColor.sum() == 0) 
+    if (tcColor.sum() == 0)
       valueSum = 16000;
     else {
 
       for(int t=0;t < Move::typeCount;t++)
-	moveValueSum += _evalScheme->moveValue(t) * 
+	moveValueSum += _evalScheme->moveValue(t) *
 	  (tcOpponent.get(t) - tcColor.get(t));
-      
+
       for(int i=0;i < InARowCounter::inARowCount;i++)
-	inARowValueSum += _evalScheme->inARowValue(i) * 
+	inARowValueSum += _evalScheme->inARowValue(i) *
 	  (ccOpponent.get(i) - ccColor.get(i));
-      
+
       if (color == color2)
-	stoneValueSum = _evalScheme->stoneValue(14 - color1Count) - 
+	stoneValueSum = _evalScheme->stoneValue(14 - color1Count) -
 	  _evalScheme->stoneValue(14 - color2Count);
       else
-	stoneValueSum = _evalScheme->stoneValue(14 - color2Count) - 
+	stoneValueSum = _evalScheme->stoneValue(14 - color2Count) -
 	  _evalScheme->stoneValue(14 - color1Count);
-      
-      valueSum = fieldValueSum + moveValueSum + 
+
+      valueSum = fieldValueSum + moveValueSum +
 	inARowValueSum + stoneValueSum;
     }
   }
@@ -895,35 +895,35 @@ bool Board::isConsistent()
 {
   int c1 = 0, c2 = 0;
   int i,j;
-  
-  for(i=0;i<RealFields;i++) {		  
+
+  for(i=0;i<RealFields;i++) {
     j=field[order[i]];
     if (j == color1) c1++;
     if (j == color2) c2++;
   }
-  return (color1Count == c1 && color2Count == c2); 
+  return (color1Count == c1 && color2Count == c2);
 }
 
 void Board::changeEvaluation()
 {
   int i,tmp;
-  
+
   /* innermost ring */
   tmp=fieldValue[1];
   for(i=1;i<6;i++)
     fieldValue[i] = fieldValue[i+1];
   fieldValue[6] = tmp;
-  
+
   tmp=fieldValue[7];
   for(i=7;i<18;i++)
     fieldValue[i] = fieldValue[i+1];
   fieldValue[18] = tmp;
-  
+
   tmp=fieldValue[19];
   for(i=19;i<36;i++)
     fieldValue[i] = fieldValue[i+1];
   fieldValue[36] = tmp;
-  
+
   /* the outermost ring */
   tmp=fieldValue[37];
   for(i=37;i<60;i++)
@@ -933,9 +933,9 @@ void Board::changeEvaluation()
 
 /*
 void Board::showHist()
-{	
+{
 	Move m1, m2;
-	
+
 	printf("After playing ");
 	(m1=lastMove()).print();
 	print();
@@ -967,7 +967,7 @@ int Board::search(int depth, int alpha, int beta)
 
 	/* We make a depth search for the following move types... */
 	int maxType = (depth < maxDepth-1)  ? Move::maxMoveType() :
-	              (depth < maxDepth)    ? Move::maxPushType() : 
+	              (depth < maxDepth)    ? Move::maxPushType() :
 	                                      Move::maxOutType();
 
 	generateMoves(list);
@@ -984,21 +984,22 @@ int Board::search(int depth, int alpha, int beta)
 	  printf("%s (%6d .. %6d) MaxType %s\n", depth,
 	  (color==color1)?"O":"X", alpha,beta,
 		 (depth < maxDepth-1) ? "Moving" :
-		 (depth < maxDepth)? "Pushing" : "PushOUT" ); 
+		 (depth < maxDepth)? "Pushing" : "PushOUT" );
 	}
 	*/
 #endif
-	
+
 	/* check for a old best move in main combination */
 	if (inPrincipalVariation) {
 	  m = pv[depth];
-	  if (!list.isElement(m, 0, true)) 
+          if ((m.type != Move::none) &&
+              (!list.isElement(m, 0, true)))
 	    m.type = Move::none;
 	  if (m.type == Move::none)
 	    inPrincipalVariation = false;
 #ifdef MYTRACE
 	  else {
-	    if (spyLevel>1) {		 
+	    if (spyLevel>1) {
 	      indent(spyDepth);
 	      printf("Got from pv !\n" );
 	    }
@@ -1014,7 +1015,7 @@ int Board::search(int depth, int alpha, int beta)
 	  stop = !list.getNext(m, maxType);
 
 	/* depth first search */
-	while(!stop) {	  
+	while(!stop) {
 
 #ifdef MYTRACE
 
@@ -1030,7 +1031,7 @@ int Board::search(int depth, int alpha, int beta)
 	  int oldPushCount = pushCount;
 	  int oldOutCount = outCount;
 	  int oldCutoffCount = cutoffCount;
-	  
+
 	  if (spyLevel>1) {
 	    indent(spyDepth);
 	    printf("%s [%6d .. %6d] ",
@@ -1038,8 +1039,8 @@ int Board::search(int depth, int alpha, int beta)
 	    m.print();
 	    printf("\n");
 	  }
-#endif	
-		
+#endif
+
 #ifdef SPION
 	  if (bUpdateSpy) emit update(depth, 0, m, false);
 #endif
@@ -1053,19 +1054,19 @@ int Board::search(int depth, int alpha, int beta)
 #endif
 	  }
 	  else {
-	    
+
 	    /* opponent searches for his maximum; but we want the
 	     * minimum: so change sign (for alpha/beta window too!)
-	     */		  
+	     */
 	    value = - search(depth+1,-beta,-alpha);
 	  }
 	  takeBack();
-	  
+
 	  /* For GUI response */
 	  if (maxDepth - depth >2)
-	    emit searchBreak();		
-	  
-#ifdef MYTRACE	
+	    emit searchBreak();
+
+#ifdef MYTRACE
 	  if (spyLevel>1) {
 
 	    indent(spyDepth);
@@ -1086,7 +1087,7 @@ int Board::search(int depth, int alpha, int beta)
 	      printf("\n");
 	      indent(spyDepth);
 	    }
-	    
+
 	    printf("  => Rated %d%s\n",
 		   value,
 		   (value>14900)  ? ", WON !":
@@ -1096,26 +1097,26 @@ int Board::search(int depth, int alpha, int beta)
 
 	  if (value>=beta) cutoffCount++;
 #endif
-	  
+
 #ifdef SPION
 	  if (bUpdateSpy) {
 	    if (value > actValue)
 	      emit updateBest(depth, value, m, value >= beta);
 	    emit update(depth, value, m, true);
-	  }		  
+	  }
 #endif
 	  if (value > actValue) {
 	    actValue = value;
 	    pv.update(depth, m);
-	    
+
 	    if (bUpdateSpy && depth == 0) {
 	      emit updateBestMove(m, actValue);
-#ifdef MYTRACE	
+#ifdef MYTRACE
 	      if (spyLevel>0) {
 		int i;
 		printf(">      New pv (Rating %d):", actValue);
 		for(i=0;i<=maxDepth;i++) {
-		  printf("\n>          D %d: %s", 
+		  printf("\n>          D %d: %s",
 			 i, (const char*)(pv[i].name()) );
 		}
 		printf("\n>\n");
@@ -1125,21 +1126,21 @@ int Board::search(int depth, int alpha, int beta)
 
 	    if (actValue>14900 || actValue >= beta)
 	      return actValue;
-	    
+
 	    /* maximize alpha */
 	    if (actValue > alpha) alpha = actValue;
 	  }
-	  
+
 	  stop = (!list.getNext(m, maxType)) || breakOut;
 	}
-	
+
 	/* other moves: calculate rating */
 	while(list.getNext(m, Move::none)) {
 
 	  if (m.isOutMove()) outCount++;
 	  else if (m.isPushMove()) pushCount++;
 	  else normalCount++;
-		
+
 	  playMove(m);
 	  if (!isValid()) {
 	    value = 14999 - depth;
@@ -1150,7 +1151,7 @@ int Board::search(int depth, int alpha, int beta)
 	  }
 	  else {
 	    ratedPositions++;
-	    
+
 	    value = calcEvaluation();
 	  }
 	  takeBack();
@@ -1160,7 +1161,7 @@ int Board::search(int depth, int alpha, int beta)
 	    if (value > actValue)
 	      emit updateBest(depth, value, m, value >= beta);
 	    emit update(depth, value, m, true);
-	  }		  
+	  }
 #endif
 
 #ifdef MYTRACE
@@ -1183,25 +1184,25 @@ int Board::search(int depth, int alpha, int beta)
 
 	    if (bUpdateSpy && depth == 0) {
 	      emit updateBestMove(m, actValue);
-#ifdef MYTRACE	
+#ifdef MYTRACE
 	      if (spyLevel>0) {
 		int i;
 		printf(">      New pv (Rating %d):", actValue);
 		for(i=0;i<=maxDepth;i++) {
-		  printf("\n>          D %d: %s", 
+		  printf("\n>          D %d: %s",
 			 i, (const char*)(pv[i].name()) );
 		}
 		printf("\n>\n");
 	      }
 #endif
 	    }
-	    
+
 	    if (actValue>14900 || actValue >= beta)
 	      return actValue;
-			
+
 	    if (actValue > alpha) alpha = actValue;
 	  }
-	}	
+	}
 	return actValue;
 }
 
@@ -1215,9 +1216,9 @@ Move& Board::bestMove()
 	  // Use default values if not set
 	  setEvalScheme();
 	}
-	
+
 	pv.clear(realMaxDepth);
-	
+
 	maxDepth=1;
 	show = false;
 	breakOut = false;
@@ -1229,7 +1230,7 @@ Move& Board::bestMove()
 	do {
 	  if (spyLevel>0)
 	    printf(">   MaxDepth: %d\n>\n", maxDepth);
-	  
+
 		// ShowTiefe(maxtiefe);
 		do {
 		  if (spyLevel>0)
@@ -1247,9 +1248,9 @@ Move& Board::bestMove()
 		  pushCount = 0;
 		  outCount = 0;
 		  cutoffCount = 0;
-		  
+
 		  actValue = search(0,alpha,beta);
-		  
+
 		  if (spyLevel>0)
 		    {
 		      int i;
@@ -1274,15 +1275,21 @@ Move& Board::bestMove()
 		    }
 
 		  /* Don't break out if we haven't found a move */
-		  if (pv[0].type == Move::none) 
+		  if (pv[0].type == Move::none)
 		    breakOut=false;
-		    
+
 		  if (actValue > 14900 || actValue < -14900)
 		    breakOut=true;
-		  if (actValue <= nalpha)
-		    alpha = -15000, beta=actValue+1;
-		  if (actValue >= nbeta)
-		    alpha = actValue-1, beta=15000;
+
+                  // widen alpha-beta window if needed
+                  if (actValue <= nalpha) {
+                    alpha = -15000;
+                    if (beta<15000) beta=actValue+1;
+                  }
+                  if (actValue >= nbeta) {
+                    if (alpha > -15000) alpha = actValue-1;
+                    beta=15000;
+                  }
 		}
 		while(!breakOut && (actValue<=nalpha || actValue>=nbeta));
 
@@ -1300,9 +1307,9 @@ Move& Board::bestMove()
 		  printf(">>> Best Move so far: %d - ", actValue);
 		  pv[0].print();
 		  printf("\n");
-		  }	
-		*/	
-	}	
+		  }
+		*/
+	}
 	while(++maxDepth< realMaxDepth && !breakOut);
 
 	/* If Spy is On, we want replayable search: don't change rating! */
@@ -1317,26 +1324,26 @@ Move& Board::bestMove()
 	spyDepth = 0;
 
 	return(pv[0]);
-}	  
+}
 
 Move Board::randomMove()
 {
 	Move m;
 	MoveList list;
-	
+
 	generateMoves(list);
 	int l = list.getLength();
 
 	int j = random.getLong(l) +1;
-	
+
 	while(j != 0) {
 		list.getNext(m, Move::none);
 		j--;
-	}	
-	
+	}
+
 	return m;
 }
-	
+
 
 void Board::print(int )
 {
@@ -1359,7 +1366,7 @@ void Board::print(int )
 		printf("/\n");
 	}
 	printf("       -----------     O: %d  X: %d\n",
-	       color1Count, color2Count);	
+	       color1Count, color2Count);
 }
 
 QString Board::getASCIIState(int moveNo)
@@ -1371,10 +1378,10 @@ QString Board::getASCIIState(int moveNo)
   const char *z[]={". ","O ","X ", "o ", "x "};
 
   state += tmp.sprintf("\n #%-3d  -----------     O: %d  X: %d\n",
-		       moveNo, color1Count, color2Count);  
+		       moveNo, color1Count, color2Count);
   for(row=0;row<4;row++) {
-    state += tmp.sprintf("%s/ ",spaces+row);    
-    for(i=0;i<5+row;i++) 
+    state += tmp.sprintf("%s/ ",spaces+row);
+    for(i=0;i<5+row;i++)
       state += tmp.sprintf("%s",z[field[row*11+12+i]]);
     state += "\\\n";
   }
@@ -1384,7 +1391,7 @@ QString Board::getASCIIState(int moveNo)
   state += "|\n";
   for(row=0;row<4;row++) {
     state += tmp.sprintf("%s\\ ",spaces+3-row);
-    for(i=0;i<8-row;i++) 
+    for(i=0;i<8-row;i++)
       state += tmp.sprintf("%s",z[field[68+row*12+i]]);
     state += "/\n";
   }
@@ -1463,18 +1470,18 @@ QString Board::getState(int moveNo)
   QString state;
   QString entry, tmp;
   int i;
-  
+
   /* Color + Counts */
   state += (char) ('A' + moveNo /25 );
   state += (char) ('A' + moveNo %25 );
   state += (char) ('A' + color1Count);
   state += (char) ('A' + color2Count);
   state += (char) ('A' + 4*color + field[order[0]]);
-  
+
   /* Board (field values can be 0-3; 2 fields coded in one char */
   for(i=1;i<61;i+=2)
     state+= (char) ('A' + 4*field[order[i]] + field[order[i+1]] );
-  
+
   /* -> 35 chars */
   return state;
 }
@@ -1491,7 +1498,7 @@ int Board::setState(QString& _state)
   color2Count = state[3] - 'A';
   color = (state[4] - 'A') / 4;
   field[order[0]] = (state[4] - 'A') %4;
-  
+
   int i = 1;
   for(int j = 5; j<35; j++) {
     int w = state[j] - 'A';
@@ -1503,6 +1510,6 @@ int Board::setState(QString& _state)
 
 void Board::setSpyLevel(int level)
 {
-  spyLevel = level;  
+  spyLevel = level;
 }
 #include "Board.moc"
