@@ -4,7 +4,7 @@
    ------------------------------------------------------------------------- */
 
 /****************************************************************************
-** $Id: GameTimer.h,v 1.1 1999/12/09 22:16:12 coolo Exp $
+** $Id: GameTimer.h,v 1.2 2001/02/18 03:31:12 waba Exp $
 **
 ** Copyright (C) 1992-1998 Troll Tech AS.  All rights reserved.
 **
@@ -19,7 +19,7 @@
 #include <qlcdnumber.h>
 #include <qdatetime.h>
 
-typedef enum TimerMode {running = -53 , stopped= -54 , paused = -55};
+enum TimerMode {running = -53 , stopped= -54 , paused = -55};
 
 class GameTimer: public QLCDNumber 
 {
