@@ -76,7 +76,7 @@ void DigitalClock::timeoutClock()
 {
     KGameLCDClock::timeoutClock();
 
-    if (_cheating) setColor(white);
+    if ( _cheating || _customGame ) setColor(white);
     else if ( _first<score() ) setColor(red);
     else if ( _last<score() ) setColor(blue);
     else setColor(white);
@@ -85,15 +85,17 @@ void DigitalClock::timeoutClock()
 void DigitalClock::start()
 {
     KGameLCDClock::start();
-    if ( !_cheating ) setColor(red);
+    if ( !_cheating && !_customGame ) setColor(red);
 }
 
-void DigitalClock::reset(const KExtHighscores::Score &first,
-                         const KExtHighscores::Score &last)
+void DigitalClock::reset(bool customGame)
 {
     _nbActions = 0;
-    _first = first;
-    _last = last;
+    _customGame = customGame;
+    if ( !customGame ) {
+        _first = KExtHighscores::firstScore();
+        _last = KExtHighscores::lastScore();
+    }
     _cheating = false;
     KGameLCDClock::reset();
     resetColor();
@@ -107,7 +109,7 @@ void DigitalClock::setCheating()
 
 //-----------------------------------------------------------------------------
 CustomConfig::CustomConfig()
-    : KConfigWidget(i18n("Custom Game"), "configure")
+    : KConfigWidget(i18n("Custom Game"), "configure"),  _block(false)
 {
 	QVBoxLayout *top = new QVBoxLayout(this, KDialog::spacingHint());
 
@@ -145,6 +147,7 @@ CustomConfig::CustomConfig()
 
 void CustomConfig::updateNbMines()
 {
+    if (_block) return;
     Level l(_width->value().toUInt(), _height->value().toUInt(),
             _mines->value().toUInt());
 	static_cast<KRangedConfigItem *>(_mines)
@@ -156,12 +159,12 @@ void CustomConfig::updateNbMines()
 
 void CustomConfig::typeChosen(int i)
 {
-    blockSignals(true);
+    _block = true;
     Level level((Level::Type)i);
     _width->setValue(level.width());
     _height->setValue(level.height());
     _mines->setValue(level.nbMines());
-    blockSignals(false);
+    _block = false;
     updateNbMines();
 }
 
