@@ -52,8 +52,7 @@ class DigitalClock : public KGameLCDClock
  public:
     DigitalClock(QWidget *parent);
 
-    void reset(const KExtHighscores::Score &first,
-               const KExtHighscores::Score &last);
+    void reset(bool customGame);
 
     bool cheating() const { return _cheating; }
     uint nbActions() const { return _nbActions; }
@@ -70,7 +69,7 @@ class DigitalClock : public KGameLCDClock
  private:
     KExtHighscores::Score _first, _last;
     uint _nbActions;
-    bool _cheating;
+    bool _cheating, _customGame;
 };
 
 //-----------------------------------------------------------------------------
@@ -78,7 +77,7 @@ class CustomConfig : public KConfigWidget, public KMines
 {
  Q_OBJECT
  public:
-	CustomConfig();
+    CustomConfig();
 
     static Level readLevel();
 
@@ -87,7 +86,8 @@ class CustomConfig : public KConfigWidget, public KMines
     void typeChosen(int);
 
  private:
-	KConfigItem *_width, *_height, *_mines;
+    bool _block;
+    KConfigItem *_width, *_height, *_mines;
     KComboBox   *_gameType;
 };
 
