@@ -69,7 +69,7 @@ class Item
      * </ul>
      */
     enum Special { NoSpecial, ZeroNotDefined, NegativeNotDefined,
-                   Anonymous };
+                   DefaultNotDefined, Anonymous };
 
     /**
      * Constructor.
@@ -166,12 +166,12 @@ class MeanScoreItem : public Item
 };
 
 /**
- * @ref Item for the best highscore. 0 is shown as "--".
+ * @ref Item for the best highscore. worstScore is shown as "--".
  */
 class BestScoreItem : public Item
 {
  public:
-    BestScoreItem();
+    BestScoreItem(uint worstScore = 0);
 };
 
 //-----------------------------------------------------------------------------
@@ -274,6 +274,6 @@ class Score : public DataArray
 QDataStream &operator <<(QDataStream &stream, const Score &score);
 QDataStream &operator >>(QDataStream &stream, Score &score);
 
-}; // namespace
+} // namespace
 
 #endif
