@@ -29,30 +29,61 @@
 #include <pile.h>
 #include <kdebug.h>
 #include <assert.h>
+#include "cardmaps.h"
+
+class KlondikePile : public Pile
+{
+public:
+    KlondikePile( int _index, Dealer* parent)
+        : Pile(_index, parent) {}
+
+    void clearSpread() { cardlist.clear(); }
+
+    void addSpread(Card *c) {
+        cardlist.append(c);
+    }
+    virtual QSize cardOffset( bool _spread, bool, const Card *c) const {
+        kdDebug() << "cardOffset " << _spread << " " << (c? c->name() : "(null)") << endl;
+        if (cardlist.contains(const_cast<Card * const>(c)))
+            return QSize(+dspread(), 0);
+        return QSize(0, 0);
+    }
+private:
+    CardList cardlist;
+};
 
 Klondike::Klondike( bool easy, KMainWindow* parent, const char* _name )
   : Dealer( parent, _name )
 {
-    deck = new Deck(13, this);
-    deck->move(10, 10);
+    // The units of the follwoing constants are pixels
+    const int margin = 10; // between card piles and board edge
+    const int hspacing = cardMap::CARDX() / 6 + 1; // horizontal spacing between card piles
+    const int vspacing = cardMap::CARDY() / 4; // vertical spacing between card piles
+
+    deck = Deck::new_deck(this);
+    deck->move(margin, margin);
 
     EasyRules = easy;
 
-    pile = new Pile( 0, this);
-    pile->move(100, 10);
+    pile = new KlondikePile( 13, this);
+
+    pile->move(margin + cardMap::CARDX() + cardMap::CARDX() / 4, margin);
+    // Move the visual representation of the pile to the intended position
+    // on the game board.
+
     pile->setAddFlags(Pile::disallow);
     pile->setRemoveFlags(Pile::Default);
 
     for( int i = 0; i < 7; i++ ) {
         play[ i ] = new Pile( i + 5, this);
-        play[i]->move(10 + 85 * i, 130);
+        play[i]->move(margin + (cardMap::CARDX() + hspacing) * i, margin + cardMap::CARDY() + vspacing);
         play[i]->setAddType(Pile::KlondikeStore);
         play[i]->setRemoveFlags(Pile::several | Pile::autoTurnTop | Pile::wholeColumn);
     }
 
     for( int i = 0; i < 4; i++ ) {
         target[ i ] = new Pile( i + 1, this );
-        target[i]->move(265 + i * 85, 10);
+        target[i]->move(margin + (3 + i) * (cardMap::CARDX()+ hspacing), margin);
         target[i]->setAddType(Pile::KlondikeTarget);
         if (EasyRules) // change default
             target[i]->setRemoveFlags(Pile::Default);
@@ -163,17 +194,25 @@ void Klondike::deal3()
 {
     int draw;
 
-    if ( EasyRules) {
+    if ( EasyRules ) {
         draw = 1;
     } else {
         draw = 3;
     }
 
+    pile->clearSpread();
+
     if (deck->isEmpty())
     {
         redeal();
         return;
     }
+
+    // move the cards back on the deck, so we can have three new
+    for (int i = 0; i < pile->cardsLeft(); ++i) {
+        pile->at(i)->move(pile->x(), pile->y());
+    }
+
     for (int flipped = 0; flipped < draw ; ++flipped) {
 
         Card *item = deck->nextCard();
@@ -181,11 +220,13 @@ void Klondike::deal3()
             kdDebug(11111) << "deck empty!!!\n";
             return;
         }
-        pile->add(item, true, false); // facedown, nospread
+        pile->add(item, true, true); // facedown, nospread
+        if (flipped < draw - 1)
+            pile->addSpread(item);
         // move back to flip
         item->move(deck->x(), deck->y());
 
-        item->flipTo( int(pile->x()), int(pile->y()), 8 * (flipped + 1) );
+        item->flipTo( int(pile->x()) + pile->dspread() * (flipped), int(pile->y()), 8 * (flipped + 1) );
     }
 
 }
@@ -212,14 +253,18 @@ void Klondike::deal() {
             play[i]->add(deck->nextCard(), i != round, true);
 }
 
-void Klondike::cardClicked(Card *c) {
+bool Klondike::cardClicked(Card *c) {
     kdDebug(11111) << "card clicked " << c->name() << endl;
 
-    Dealer::cardClicked(c);
+    if (Dealer::cardClicked(c))
+        return true;
+
     if (c->source() == deck) {
         pileClicked(deck);
-        return;
+        return true;
     }
+
+    return false;
 }
 
 void Klondike::pileClicked(Pile *c) {
@@ -248,4 +293,12 @@ public:
     virtual Dealer *createGame(KMainWindow *parent) { return new Klondike(true, parent); }
 } ldi0;
 
+static class LocalDealerInfo14 : public DealerInfo
+{
+public:
+    LocalDealerInfo14() : DealerInfo(I18N_NOOP("Klondike (&draw 3)"), 14) {}
+    virtual Dealer *createGame(KMainWindow *parent) { return new Klondike(false, parent); }
+} ldi14;
+
+
 #include "klondike.moc"
