@@ -56,13 +56,16 @@ int main( int argc, char **argv )
     KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
 
     KApplication a;
+    KGlobal::locale()->insertCatalogue("libkdegames");
 
-    pWidget* p = new pWidget("pwidget");
+    if (a.isRestored())
+        RESTORE(pWidget)
+    else {
+        pWidget *w = new pWidget;
     if (args->count())
-        p->openGame(args->url(0));
-    p->show();
-
-    a.setMainWidget(p);
-    int r = a.exec();
-    return r;
+            w->openGame(args->url(0));
+        a.setMainWidget(w);
+        w->show();
+    }
+    return a.exec();
 }
