@@ -1,19 +1,23 @@
 #include "simon.h"
 #include <klocale.h>
+#include <kdebug.h>
 #include "pile.h"
 #include "deck.h"
 #include <assert.h>
+#include "cardmaps.h"
 
 Simon::Simon( KMainWindow* parent, const char *name )
     : Dealer( parent, name )
 {
-    deck = new Deck(0, this);
+    deck = Deck::new_deck(this);
     deck->move(10, 10);
     deck->hide();
 
+    const int dist_x = cardMap::CARDX() * 11 / 10 + 1;
+
     for (int i=0; i<4; i++) {
         target[i] = new Pile(i+1, this);
-        target[i]->move(250+i*80, 10);
+        target[i]->move(10+(i+3)*dist_x, 10);
         target[i]->setRemoveFlags(Pile::disallow);
         target[i]->setAddFlags(Pile::several);
         target[i]->setCheckIndex(0);
@@ -22,7 +26,7 @@ Simon::Simon( KMainWindow* parent, const char *name )
 
     for (int i=0; i<10; i++) {
         store[i] = new Pile(5+i, this);
-        store[i]->move(15+80*i, 150);
+        store[i]->move(15+dist_x*i, 10 + cardMap::CARDY() * 73 / 50);
         store[i]->setAddFlags(Pile::addSpread | Pile::several);
         store[i]->setRemoveFlags(Pile::several);
         store[i]->setCheckIndex(1);
@@ -106,6 +110,43 @@ bool Simon::checkRemove(int checkIndex, const Pile *p, const Card *c) const
     return true;
 }
 
+bool Simon::isGameLost() const
+{
+	kdDebug(11111) <<"isGameLost" << endl;
+    for (int i=0; i<10; i++) {
+		if(store[i]->isEmpty())
+			return false;
+	kdDebug(11111) <<"store["<<i<<"]" << endl;
+
+		Card *c;
+		Card *top=store[i]->top();
+		int indexi=store[i]->indexOf(top);
+		while(--indexi >=0){
+		kdDebug(11111) <<top->name() << endl;
+			c=store[i]->at(indexi);
+			if(c->suit() == top->suit() &&
+				(top->value()+1) == c->value())
+				top=c;
+			else
+				break;
+			}
+
+		kdDebug(11111) <<"selected: " << top->name() << endl;
+		for(int j=1; j <10; j++){
+			int k=(i+j) % 10;
+
+			if(store[k]->isEmpty())
+				return false;
+
+			kdDebug(11111) <<"vs "<<store[k]->top()->name() << endl;
+			if((top->value() +1) == store[k]->top()->value())
+				return false;
+			}
+		}
+
+	return true;
+}
+
 static class LocalDealerInfo9 : public DealerInfo
 {
 public:
