@@ -16,14 +16,10 @@
 
 // QT includes
 #include <qdir.h>
-#include <qlabel.h>
 #include <qlayout.h>
 
 // KDE includes
-#include <kglobal.h>
-#include <kstandarddirs.h>
-#include <kiconloader.h>
-#include <kapplication.h>
+//#include <kglobal.h>
 #include <kdebug.h>
 
 // own includes
