@@ -14,19 +14,15 @@
  *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
     
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 
 #include "version.h"
-#include "global.h"
 #include "top.h"
 
-
-static const char *description = I18N_NOOP("KDE Card Game");
-
-KConfig *conf;
+static const char *description = I18N_NOOP("KDE Poker Game");
 
 int main( int argc, char *argv[] )
 {
@@ -35,23 +31,24 @@ int main( int argc, char *argv[] )
 		"(c) 1997-2000 Jochen Tuchbreiter, Andreas Beckermann", 
 		I18N_NOOP("For a full list of credits see helpfile\nAny suggestions, bug reports etc. are welcome"));
 
-	aboutData.addAuthor("Andreas Beckermann", I18N_NOOP("Current maintainer"), "b_mann@gmx.de");
-	aboutData.addAuthor("Jochen Tuchbreiter", I18N_NOOP("Original author"), "whynot@mabi.de");
+	aboutData.addAuthor("Andreas Beckermann", 
+			I18N_NOOP("Current maintainer"), "b_mann@gmx.de");
+	aboutData.addAuthor("Jochen Tuchbreiter", 
+			I18N_NOOP("Original author"), "whynot@mabi.de");
 	KCmdLineArgs::init( argc, argv, &aboutData );
 
 	KApplication myApp;
-	PokerWindow *MainScreen = new PokerWindow;
-
+	KGlobal::locale()->insertCatalogue("libkdegames");
+	 
+	
 	if (myApp.isRestored()) {
-	  if (KTMainWindow::canBeRestored(1))
-	    MainScreen->restore(1);
+		RESTORE(PokerWindow)
+	}
+	else {
+		PokerWindow *MainScreen = new PokerWindow;
+		myApp.setMainWidget( MainScreen );
+		MainScreen->show();
 	}
 
-	myApp.setMainWidget( MainScreen );
-	MainScreen->show();
-		  
-	int ret = myApp.exec();
-		  
-	return ret;
-
+	return myApp.exec();
 }
