@@ -23,7 +23,6 @@
 // KDE includes
 #include <kapplication.h>
 #include <kglobal.h>
-#include <kaccel.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kcarddialog.h>
@@ -45,21 +44,6 @@ void kpok::initSomeStuff()
 
  blinking = true;
 
-// KKeyCode initialization
- kacc = new KAccel( this );
- kacc->insertItem(i18n("Draw"), "Draw", Key_Return);
- kacc->connectItem("Draw", this, SLOT(drawClick())); // same as drawButton
- kacc->insertItem(i18n("Exchange Card 1"), "ExchangeCard1", Key_1);
- kacc->connectItem("ExchangeCard1", this, SLOT(exchangeCard1()));
- kacc->insertItem(i18n("Exchange Card 2"), "ExchangeCard2", Key_2);
- kacc->connectItem("ExchangeCard2", this, SLOT(exchangeCard2()));
- kacc->insertItem(i18n("Exchange Card 3"), "ExchangeCard3", Key_3);
- kacc->connectItem("ExchangeCard3", this, SLOT(exchangeCard3()));
- kacc->insertItem(i18n("Exchange Card 4"), "ExchangeCard4", Key_4);
- kacc->connectItem("ExchangeCard4", this, SLOT(exchangeCard4()));
- kacc->insertItem(i18n("Exchange Card 5"), "ExchangeCard5", Key_5);
- kacc->connectItem("ExchangeCard5", this, SLOT(exchangeCard5()));
-
  QFont myFixedFont;
  myFixedFont.setPointSize(12);
  QFont wonFont;
@@ -76,7 +60,7 @@ void kpok::initSomeStuff()
  topInputLayout->addLayout(inputLayout);
 
  drawButton = new QPushButton(this);
- drawButton->setText(i18n("&Draw!"));
+ drawButton->setText(i18n("&Draw"));
  connect(drawButton, SIGNAL(clicked()), this, SLOT(drawClick()));
  inputLayout->addWidget(drawButton);
  inputLayout->addStretch(1);
