@@ -28,25 +28,28 @@
 #include "version.h"
 #include "KSameWidget.h"
 #include <kaboutdata.h>
+#include <kglobal.h>
 
 static const char *description = I18N_NOOP("Same Game - a little game about balls and how to get rid of them");
+static const char *copyright = "(c) 1997-1998 Marcus Kreutzberger";
 
 int main( int argc, char **argv ) {
 	KAboutData aboutData("ksame", I18N_NOOP("SameGame"), KSAME_VERSION,
-						  description, KAboutData::License_GPL);
-	 aboutData.addAuthor("Marcus Kreutzberger", 0, "kreutzbe@informatik.mu-luebeck.de");
-	 KCmdLineArgs::init(argc, argv, &aboutData);
-	
-	 KApplication::setColorSpec(QApplication::ManyColor+QApplication::CustomColor);
-	 KApplication a;
-	
-	 KSameWidget *w = new KSameWidget;
-	 if (kapp->isRestored()) {
-		 if (KSameWidget::canBeRestored(1))
-			 w->restore(1);
-	 } else
-		 w->show();
-	 a.setMainWidget(w);
-	
-	 return a.exec();
+                         description, KAboutData::License_GPL, copyright);
+    aboutData.addAuthor("Marcus Kreutzberger", 0, "kreutzbe@informatik.mu-luebeck.de");
+    KCmdLineArgs::init(argc, argv, &aboutData);
+
+    KApplication::setColorSpec(QApplication::ManyColor+QApplication::CustomColor);
+    KApplication a;
+    KGlobal::locale()->insertCatalogue("libkdegames");
+
+    KSameWidget *w = new KSameWidget;
+    if (kapp->isRestored()) {
+        if (KSameWidget::canBeRestored(1))
+            w->restore(1);
+    } else
+        w->show();
+    a.setMainWidget(w);
+
+    return a.exec();
 }
