@@ -31,7 +31,7 @@ this software.
 #include "gamewindow.h"
 
 
-static const char *description = I18N_NOOP("KDE Game");
+static const char *description = I18N_NOOP("KDE SmileTris");
 
 
 int main(int argc, char **argv)
