@@ -1,12 +1,6 @@
 #ifndef GAME_H
 #define GAME_H
 
-#include <kmenubar.h>
-#include <qpopupmenu.h>
-
-#include <qptrlist.h>
-#include <qfileinfo.h>
-
 #include <kmainwindow.h>
 
 class Rattler;
@@ -64,9 +58,9 @@ private:
 
     KAction *pause;
     KSelectAction *balls;
-	KSelectAction *ballsAI;
+    KSelectAction *ballsAI;
     KSelectAction *snakes;
-	KSelectAction *snakesAI;
+    KSelectAction *snakesAI;
     KRadioAction *skills[4];
     KSelectAction *pix;
 
