@@ -4,6 +4,8 @@
 #include <qkeycode.h>
 #include <qpixmap.h>
 #include <qstring.h>
+#include <qlayout.h>
+#include <qevent.h>
 
 #include <kaccel.h>
 #include <kapplication.h>
@@ -15,74 +17,59 @@
 #include <kconfig.h>
 
 Keys::Keys( QWidget *parent, const char *name, int player)
-    : QDialog( parent, name, TRUE )
+    : KDialogBase( parent, name, true, i18n("Change Direction Keys"),
+    KDialogBase::Ok|KDialogBase::Cancel|KDialogBase::Default, KDialogBase::Ok, true )
 {
-	playerNum = player;
+    QWidget *page = new QWidget( this );
+    QGridLayout *layout = new QGridLayout(page, 7, 7, marginHint(), 0);
+    setMainWidget(page);
 
-    QPushButton *okButton  = new QPushButton(this);
-    okButton->setText(i18n("OK"));
-    okButton->setFixedSize(okButton->size());
-    connect( okButton, SIGNAL(clicked()),this, SLOT(ok()) );
-    okButton->move(20,210);
+    playerNum = player;
 
-    QPushButton *defaultButton  = new QPushButton(this);
-    defaultButton->setText(i18n("Defaults"));
-    defaultButton->setFixedSize(defaultButton->size());
-    connect( defaultButton, SIGNAL(clicked()),this, SLOT(defaults()) );
-    defaultButton->move(140,210);
-
-    QPushButton *cancelButton  = new QPushButton(this);
-    cancelButton->setText(i18n("Cancel"));
-    cancelButton->setFixedSize(cancelButton->size());
-    connect( cancelButton, SIGNAL(clicked()),this, SLOT(reject()) );
-    cancelButton->move(260,210);
-
-    QFrame *separator = new QFrame(this);
-    separator->setFrameStyle( QFrame::HLine | QFrame::Sunken );
-    separator->setGeometry( 20, 190, 340, 4 );
+    connect( this, SIGNAL(okClicked()), SLOT(ok()) );
+    connect( this, SIGNAL(defaultClicked()), SLOT(defaults()) );
 
     for ( int x = 0; x < 4; x++) {
-	labels[x] = new QLabel(this);
+	labels[x] = new QLabel(page);
 	labels[x]->setAlignment(AlignCenter);
+	labels[x]->setFixedSize(100, labels[x]->sizeHint().height()+2);
     }
 
-    labels[0]->setGeometry(120, 20, 140, 20 );
-    labels[1]->setGeometry(120,160, 140, 20 );
-    labels[2]->setGeometry( 20, 92, 100, 20 );
-    labels[3]->setGeometry(265, 92, 100, 20 );
-
-
-    QPushButton *up = new QPushButton(this);
+    QPushButton *up = new QPushButton(page);
     up->setPixmap( BarIcon("up"));
-    up->adjustSize();
-    up->setFixedSize(up->size() );
+    up->setFixedSize(up->sizeHint() );
     connect( up, SIGNAL(clicked()),this, SLOT(butUp()) );
-    up->move(180, 50);
 
-    QPushButton *down = new QPushButton(this);
+    QPushButton *down = new QPushButton(page);
     down->setPixmap( BarIcon("down"));
-    down->adjustSize();
-    down->setFixedSize(down->size() );
+    down->setFixedSize(down->sizeHint() );
     connect( down, SIGNAL(clicked()),this, SLOT(butDown()) );
-    down->move(180, 130);
 
-    QPushButton *left = new QPushButton(this);
+    QPushButton *left = new QPushButton(page);
     left->setPixmap( BarIcon("back"));
-    left->adjustSize();
-    left->setFixedSize(left->size() );
+    left->setFixedSize(left->sizeHint() );
     connect( left, SIGNAL(clicked()),this, SLOT(butLeft()) );
-    left->move(140, 90);
 
-    QPushButton *right = new QPushButton(this);
+    QPushButton *right = new QPushButton(page);
     right->setPixmap( BarIcon("forward"));
-    right->adjustSize();
-    right->setFixedSize(right->size() );
+    right->setFixedSize(right->sizeHint() );
     connect( right, SIGNAL(clicked()),this, SLOT(butRight()) );
-    right->move(220, 90);
 
+    layout->addMultiCellWidget(labels[0], 0, 0, 2, 4, AlignCenter);
+    layout->addMultiCellWidget(labels[1], 6, 6, 2, 4, AlignCenter);
+    layout->addWidget(labels[2], 3, 1, AlignCenter);
+    layout->addWidget(labels[3], 3, 5, AlignCenter);
+    layout->addWidget(up, 2, 3);
+    layout->addWidget(down, 4, 3);
+    layout->addWidget(left, 3, 2);
+    layout->addWidget(right, 3, 4);
 
-    setCaption(i18n("Change Direction Keys"));
-    setFixedSize(380, 260);
+    layout->setRowStretch(0, 1);
+    layout->addRowSpacing(1, spacingHint());
+    layout->addRowSpacing(5, spacingHint());
+    layout->setRowStretch(6, 1);
+    layout->setColStretch(0, 1);
+    layout->setColStretch(6, 1);
     lab = 0;
     init();
 }
@@ -131,6 +118,7 @@ void Keys::getKey(int i)
 
 void Keys::focusOut(QLabel *l)
 {
+    l->setFocusPolicy(NoFocus); 
     l->setFrameStyle( QFrame::NoFrame );
     l->setBackgroundColor(backgroundColor());
     l->repaint();
@@ -139,6 +127,8 @@ void Keys::focusOut(QLabel *l)
 void Keys::focusIn(QLabel *l)
 {
     lab = l;
+    lab->setFocusPolicy(ClickFocus); 
+    lab->setFocus(); 
     lab->setFrameStyle( QFrame::Panel | QFrame::Sunken );
     lab->setBackgroundColor(white);
     lab->repaint();
