@@ -2,7 +2,6 @@
 
 #include <qobject.h>
 #include <qdatastream.h>
-#include <qfile.h>
 #include <qstring.h>
 #include <qpushbutton.h>
 #include <qframe.h>
@@ -60,7 +59,7 @@ QString Score::getPlayerName() {
     QDialog *dlg = new QDialog(0, "Hall Of Fame", TRUE);
     dlg->resize(300, 175);
     dlg->setCaption(i18n("Snake Race High Scores"));
-    QLabel *label  = new QLabel(i18n("you have achieved a high score!\n please enter your name"),
+    QLabel *label  = new QLabel(i18n("You have achieved a high score!\nPlease enter your name"),
 				dlg);
     label->setAlignment(AlignCenter);
     label->setFont( QFont( "Times", 14, QFont::Bold ) );
