@@ -22,11 +22,10 @@
 #include <qtimer.h>
 
 #include <kdebug.h>
-#include <kapplication.h>
-#include <kaccel.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kcolordialog.h>
+#include <kaction.h>
 
 #include "tron.h"
 
@@ -176,7 +175,8 @@ void Tron::stopGame()
 {
    timer->stop();
    gameEnded=true;
-
+   players[0].last_dir = None;
+   players[1].last_dir = None;
 }
 
 void Tron::togglePause() // pause or continue game
@@ -385,9 +385,9 @@ void Tron::drawRect(QPainter & p, int x, int y)
 **                    config functions										 **
 ** *************************************************************** */
 
-void Tron::setAccel(KAccel *acc)
+void Tron::setActionCollection(KActionCollection *a)
 {
-   accel=acc;
+   actionCollection = a;
 }
 
 void Tron::setBackgroundPix(QPixmap pix)
@@ -604,13 +604,13 @@ void Tron::switchDir(int playerNr,Direction newDirection)
 
   if (oppositeDirCrashes()==false)
   {
-    if (newDirection==::Up && players[playerNr].dir==::Down)
+    if (newDirection==::Up && players[playerNr].last_dir==::Down)
       return;
-    if (newDirection==::Down && players[playerNr].dir==::Up)
+    if (newDirection==::Down && players[playerNr].last_dir==::Up)
       return;
-    if (newDirection==::Left && players[playerNr].dir==::Right)
+    if (newDirection==::Left && players[playerNr].last_dir==::Right)
       return;
-    if (newDirection==::Right && players[playerNr].dir==::Left)
+    if (newDirection==::Right && players[playerNr].last_dir==::Left)
       return;
   }
 
@@ -643,6 +643,7 @@ void Tron::updateDirections(int playerNr)
             playfield[x][y] &= (~LEFT);
             break;
       }
+      players[0].last_dir = players[0].dir;
 
    }
    if(playerNr==-1 || playerNr==1)
@@ -669,6 +670,7 @@ void Tron::updateDirections(int playerNr)
              playfield[x][y] &= (~LEFT);
              break;
       }
+      players[1].last_dir = players[1].dir;
 
    }
 
@@ -751,62 +753,60 @@ void Tron::resizeEvent(QResizeEvent *)
 
 void Tron::keyPressEvent(QKeyEvent *e)
 {
-  int key=e->key();
-
+  KKey key(e);
   if(!players[1].computer)
   {
-      if(key==accel->shortcut("Pl2Up"))
+      if(actionCollection->action("Pl2Up")->shortcut().contains(key))
 		{
 	  		switchDir(1,::Up);
 	  		players[1].keyPressed=true;
 		}
-      else if(key==accel->shortcut("Pl2Left"))
+      else if(actionCollection->action("Pl2Left")->shortcut().contains(key))
 	   {
 	  		switchDir(1,::Left);
 	  		players[1].keyPressed=true;
 		}
-      else if(key==accel->shortcut("Pl2Right"))
+      else if(actionCollection->action("Pl2Right")->shortcut().contains(key))
 		{
 	  		switchDir(1,::Right);
 	  		players[1].keyPressed=true;
 		}
-      else if(key==accel->shortcut("Pl2Down"))
+      else if(actionCollection->action("Pl2Down")->shortcut().contains(key))
 		{
 	  		switchDir(1,::Down);
 	  		players[1].keyPressed=true;
 		}
-      else if(key==accel->shortcut("Pl2Ac"))
+      else if(actionCollection->action("Pl2Ac")->shortcut().contains(key))
 		{
 		   if(!blockAccelerator)
 	  			players[1].accelerated=true;
-		}
 
+		}
   }
 
   if(!players[0].computer)
   {
-      if(key==accel->shortcut("Pl1Left"))
+      if(actionCollection->action("Pl1Left")->shortcut().contains(key))
 		{
 	  		switchDir(0,::Left);
 	  		players[0].keyPressed=true;
 		}
-      else if(key==accel->shortcut("Pl1Right"))
+      else if(actionCollection->action("Pl1Right")->shortcut().contains(key))
 		{
 	  		switchDir(0,::Right);
 	  		players[0].keyPressed=true;
 		}
-      else if(key==accel->shortcut("Pl1Up"))
+      else if(actionCollection->action("Pl1Up")->shortcut().contains(key))
 		{
 	  		switchDir(0,::Up);
 	  		players[0].keyPressed=true;
 		}
-      else if(key==accel->shortcut("Pl1Down"))
+      else if(actionCollection->action("Pl1Down")->shortcut().contains(key))
 		{
 	 		switchDir(0,::Down);
 	  		players[0].keyPressed=true;
 		}
-
-      else if(key==accel->shortcut("Pl1Ac"))
+      else if(actionCollection->action("Pl1Ac")->shortcut().contains(key))
 		{
 		   if(!blockAccelerator)
 	  			players[0].accelerated=true;
@@ -816,83 +816,80 @@ void Tron::keyPressEvent(QKeyEvent *e)
   e->ignore();  // if key is unknown: ignore
 
   // if both players press keys at the same time, start game...
-
-	if(gameEnded && !gameBlocked)
-  	{
-  		if(players[0].keyPressed && players[1].keyPressed)
-		{
-	   	reset();
-	   	startGame();
-		}
+  if(gameEnded && !gameBlocked)
+  {
+	if(players[0].keyPressed && players[1].keyPressed)
+	{
+		reset();
+		startGame();
 	}
-
-  	// ...or continue
-  	else if(gamePaused)
-   {
-      if(players[0].keyPressed && players[1].keyPressed)
-		{
-		   togglePause();
-		}
+  }
+  // ...or continue
+  else if(gamePaused)
+  {
+	if(players[0].keyPressed && players[1].keyPressed)
+	{
+	   togglePause();
 	}
+  }
 }
 
 void Tron::keyReleaseEvent(QKeyEvent * e)
 {
-  int key=e->key();
+  KKey key(e);
 
   if(!players[1].computer)
   {
-      if(key==accel->shortcut("Pl2Ac"))
-	   {
-	      players[1].accelerated=false;
-	      return;
+      if(actionCollection->action("Pl2Ac")->shortcut().contains(key))
+		{
+			players[1].accelerated=false;
+			return;
   		}
-
-		else if(key==accel->shortcut("Pl2Left"))
+      else if(actionCollection->action("Pl2Left")->shortcut().contains(key))
+		{
+			players[1].keyPressed=false;
+			return;
+		}
+      else if(actionCollection->action("Pl2Right")->shortcut().contains(key))
 		{
 	  		players[1].keyPressed=false;
 	  		return;
 		}
-      else if(key==accel->shortcut("Pl2Right"))
+      else if(actionCollection->action("Pl2Up")->shortcut().contains(key))
 		{
 	  		players[1].keyPressed=false;
 	  		return;
 		}
-      else if(key==accel->shortcut("Pl2Up"))
-		{
-	  		players[1].keyPressed=false;
-	  		return;
-		}
-      else if(key==accel->shortcut("Pl2Down"))
+      else if(actionCollection->action("Pl2Down")->shortcut().contains(key))
 		{
 		  players[1].keyPressed=false;
 		  return;
 		}
   }
 
-	if(!players[0].computer)
+   if(!players[0].computer)
    {
-   	if(key==accel->shortcut("Pl1Left"))
-    	{
+      if(actionCollection->action("Pl1Left")->shortcut().contains(key))
+		{
 	 		players[0].keyPressed=false;
 	 		return;
-    	}
-      else if(key==accel->shortcut("Pl1Right"))
+		}
+      else if(actionCollection->action("Pl1Right")->shortcut().contains(key))
 		{
 	  		players[0].keyPressed=false;
 	  		return;
 		}
-      else if(key==accel->shortcut("Pl1Up"))
+      else if(actionCollection->action("Pl1Up")->shortcut().contains(key))
 		{
 	 		players[0].keyPressed=false;
 	  		return;
 		}
-     	else if(key==accel->shortcut("Pl1Down"))
+      else if(actionCollection->action("Pl1Down")->shortcut().contains(key))
 		{
 	 		players[0].keyPressed=false;
 	 		return;
 		}
-      else if(key==accel->shortcut("Pl1Ac"))
+      else if(actionCollection->action("Pl1Ac")->shortcut().contains(key))
 		{
 	  		players[0].accelerated=false;
 	  		return;
