@@ -12,10 +12,6 @@
 #include <qlabel.h>
 #include <qpushbutton.h>
 #include <qlayout.h>
-#include <qvariant.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
-#include <qimage.h>
 #include <qpixmap.h>
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -33,7 +29,7 @@ StatDlg::StatDlg( QWidget* parent,  const char* name, bool modal, WFlags fl )
 {
     if ( !name ) setName( "StatDlg" );
     resize( 596, 512 ); 
-    setCaption(i18n("Statistics..."));
+    setCaption(i18n("Statistics"));
 
     Frame3 = new QFrame( this, "Frame3" );
     Frame3->setGeometry( QRect( 30, 10, 511, 461 ) ); 
@@ -49,7 +45,7 @@ StatDlg::StatDlg( QWidget* parent,  const char* name, bool modal, WFlags fl )
     vbox->setMargin( 0 );
 
     GroupBox1 = new QGroupBox( Layout17, "GroupBox1" );
-    GroupBox1->setTitle( i18n( "All time game statistics"  ) );
+    GroupBox1->setTitle( i18n( "All Time Game Statistics"  ) );
 
     QWidget* Layout10 = new QWidget( GroupBox1, "Layout10" );
     Layout10->setGeometry( QRect( 10, 30, 399, 113 ) ); 
