@@ -19,9 +19,9 @@
 #include <qpixmap.h>
 #include <qcolor.h>
 #include <qrect.h>
+#include <qfontmetrics.h>
 #include <qpoint.h>
 #include <qstring.h>
-#include <qwidget.h>
 #include <qpainter.h>
 #include <qdatetime.h>
 #include <kmessagebox.h>
@@ -138,6 +138,7 @@ LSkatView::~LSkatView()
 {
 }
 
+// Access the document with the game data
 LSkatDoc *LSkatView::getDocument() const
 {
   LSkatApp *theApp=(LSkatApp *) parentWidget();
@@ -146,6 +147,11 @@ LSkatDoc *LSkatView::getDocument() const
 }
 
 // draw a border around a rect
+// p: Painter
+// rect: The rect to draw a border
+// offset: An offset to the rect to make it smaller
+// width: The width of the border
+// mode: 0: Light border, 1: dark border
 void LSkatView::drawBorder(QPainter *p,QRect rect,int offset,int width,int mode)
 {
 QPen graypen;
@@ -176,6 +182,9 @@ QPoint p1,p2;
 	}
 }
 
+// draw a move by animating the movment and turning of the
+// card. This is called until the card reaches its final
+// position
 void LSkatView::drawMove(QPainter *p)
 {
   int m1,m2;
@@ -239,17 +248,23 @@ void LSkatView::drawMove(QPainter *p)
   }
 }
 
+// Show the intro (Cards+Text)
+// This is called repeatetly
 void LSkatView::drawIntro(QPainter *p)
 {
     int i,c1,c2,x,cnt,y,col,col2,col3,col4;
+    // The window width;
+    // int win_width = p->window().width();
     QPoint point,point1,p2;
     QString s;
-    QFont font(QCString("lucida"),48,QFont::Normal,false);
+    // Get a nice font
+    QFont font("Helvetica",48,QFont::Normal,false);
     font.setPixelSize(48);
+    // Get the font info to determine text sizes
+    QFontMetrics fontMetrics(font);
 
     p->setFont(font);
 
-
     cnt=introcnt;
     if (cnt>NO_OF_CARDS) cnt=NO_OF_CARDS;
     
@@ -269,13 +284,15 @@ void LSkatView::drawIntro(QPainter *p)
       p->drawPixmap(point1+p2,getDocument()->mPixCard[c2]);
     }
 
+    // All text are positioned that they end up at x=310-textwidth/2
+    // All texts are drawn twice with different colors to produce a shadow
     col=255-8*i;
     if (col<0) col=0;
     col2=2*col/3;
     col3=255-2*i;
     col4=2*col3/3;
-    s=i18n("Lieutnant Skat");
-    x=160;
+    s=i18n("Lieutenant Skat");
+    x=310-fontMetrics.width(s)/2;
     y=-20+(int)(200.0*sin(0.5*M_PI/(float)NO_OF_CARDS*cnt));
     p->setPen(QColor(col4,col2,0));
     p->drawText(x-2,y+2,s);
@@ -285,7 +302,7 @@ void LSkatView::drawIntro(QPainter *p)
 
     s=i18n("for");
     y=270+(NO_OF_CARDS-cnt)*3;
-    x=-50+(int)(340.0*sin(0.5*M_PI/(float)NO_OF_CARDS*cnt));
+    x=-fontMetrics.width(s)/2+(int)(310.0*sin(0.5*M_PI/(float)NO_OF_CARDS*cnt));
     p->setPen(QColor(col4,col2,0));
     p->drawText(x-2,y+2,s);
 
@@ -294,7 +311,8 @@ void LSkatView::drawIntro(QPainter *p)
 
     s=i18n("K D E");
     y=350+(NO_OF_CARDS-cnt)*3;
-    x=640-(int)(380.0*sin(0.5*M_PI/(float)NO_OF_CARDS*cnt));
+    // x=640-(int)(380.0*sin(0.5*M_PI/(float)NO_OF_CARDS*cnt));
+    x=570-fontMetrics.width(s)/2-(int)(260.0*sin(0.5*M_PI/(float)NO_OF_CARDS*cnt));
     p->setPen(QColor(col4,col2,0));
     p->drawText(x-2,y+2,s);
 
@@ -302,6 +320,7 @@ void LSkatView::drawIntro(QPainter *p)
     p->drawText(x,y,s);
 }
 
+// Draw all cards to create the game board
 void LSkatView::drawDeck(QPainter *p)
 {
   int x,y,card;
@@ -348,9 +367,9 @@ void LSkatView::drawDeck(QPainter *p)
 void LSkatView::drawFinal(QPainter *p)
 {
   int sc1,sc0,pt0,pt1;
-  QPoint p1,p2;
+  //QPoint p1,p2;
   int trump;
-  QRect r;
+  //QRect r;
   QString ld;
   int ts[10];
 
@@ -397,7 +416,7 @@ void LSkatView::drawFinal(QPainter *p)
   //rect1.moveBy(0,FINAL_Y0-24);
   p->setFont(font24);
   brect1=p->boundingRect(rect,Qt::AlignHCenter|Qt::SingleLine|Qt::AlignTop,line1);
-  QRect wrect=p->window();
+  //QRect wrect=p->window();
   sumrect=brect1;
 
   if (sc0+sc1!=120)  // aborted
@@ -658,7 +677,7 @@ void LSkatView::drawStatus(QPainter *p)
       rect.setWidth(rect.width()+10);
       line2a.sprintf("%3d",getDocument()->GetScore(pl));
       line2b.sprintf("%3d",getDocument()->GetMoveNo());
-
+      
       // paint
       if (getDocument()->GetStartPlayer()==pl) p->setPen(COL_PLAYER);
       else p->setPen(black);
@@ -823,13 +842,13 @@ void LSkatView::mousePressEvent( QMouseEvent *mouse )
     switch(getDocument()->random(4))
     {
       case 0:
-        m=i18n("Hold on..the other was not yet gone...");
+        m=i18n("Hold on... the other player hasn't been yet...");
       break;
       case 1:
         m=i18n("Hold your horses...");
       break;
       case 2:
-        m=i18n("Ah ah ah...only one go at a time...");
+        m=i18n("Ah ah ah... only one go at a time...");
       break;
       default:
         m=i18n("Please wait... it is not your turn.");
