@@ -17,7 +17,7 @@
 /*
     Msgdlg.cpp
 
-    $Id: msgdlg.cpp,v 1.5 2002/01/04 20:57:09 binner Exp $
+    $Id: msgdlg.cpp,v 1.8 2002/07/09 08:43:42 binner Exp $
     
     Msg dialog for player names
     
@@ -30,8 +30,6 @@
 
 #include <qgroupbox.h>
 #include <qpushbutton.h>
-#include <qwidget.h>
-#include <qlabel.h>
 #include <klocale.h>
 #include "msgdlg.h"
 
@@ -41,13 +39,13 @@
 MsgDlg::MsgDlg( QWidget *parent, const char *name,const char * /*sufi */ )
     : QDialog( parent, name,TRUE )
 {
-  setCaption(i18n("Send Message to Remote Player..."));
+  setCaption(i18n("Send Message to Remote Player"));
   setMinimumSize(400,160);
   setMaximumSize(600,360);                                                        
   resize( 400, 160 );
 
   QGroupBox* grp;
-  grp = new QGroupBox(i18n("Enter message"), this);
+  grp = new QGroupBox(i18n("Enter Message"), this);
   grp->resize(380,100);
   grp->move(10,10);
 
